
package com.xdf.creative.base.service.impl;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.xdf.creative.base.params.QueryParam;
import com.xdf.creative.base.service.BaseService;
import com.xdf.creative.constant.CommonConstant;
import com.xdf.creative.enums.OrganizeTypeEnum;
import com.xdf.creative.shiro.jwt.JwtTokenUtil;
import com.xdf.creative.shiro.jwt.JwtUtil;
import com.xdf.creative.util.CollectionTools;
import com.xdf.creative.util.StringUtil;
import org.springframework.beans.factory.annotation.Autowired;

/**
 *
 * @param <M>
 * @param <T>
 */
public abstract class BaseServiceImpl<M extends BaseMapper<T>, T> extends ServiceImpl<M, T> implements BaseService<T> {
    @Autowired
    private JwtTokenUtil jwtTokenUtil;
    @Autowired
    private JwtUtil jwtUtil;
    /**
     * 分页排序设置
     * 默认按创建时间Desc降序排列
     *
     * @param queryParam
     * @return
     */
    protected Page setPageParam(QueryParam queryParam) {
        Page page = new Page();
        page.setCurrent(queryParam.getPageNum());
        page.setSize(queryParam.getPageSize());
        if (CollectionTools.isNoEmptyArr(queryParam.getOrder())) {
            String[] ascArray = new String[queryParam.getOrder().length];
            String[] descArray = new String[queryParam.getOrder().length];
            int ascIndex = 0;
            int descIndex = 0;
            for (int i = 0; i < queryParam.getOrder().length; i++) {
                boolean asc = false;
                if (queryParam.getOrder().length == queryParam.getDoAsc().length) {
                    asc = queryParam.getDoAsc()[i];
                } else if (1 == queryParam.getDoAsc().length) {
                    asc = queryParam.getDoAsc()[0];
                }
                if (asc) {
                    ascArray[ascIndex] = queryParam.getOrder()[i];
                    ascIndex++;
                } else {
                    descArray[descIndex] = queryParam.getOrder()[i];
                    descIndex++;
                }
            }
            if (descArray.length > 0) {
                page.setDesc(descArray);
            }
            if (ascArray.length > 0) {
                page.setAsc(ascArray);
            }
        }
        return page;
    }

    protected Page setPage(QueryParam queryParam) {
        Page page = new Page<>(queryParam.getPageNum(), queryParam.getPageSize(), true);
        return page;
    }

    @Override
    public Long getUserId() {
        String token = jwtTokenUtil.getToken();
        return jwtUtil.getUserId(token);
    }

    @Override
    public Integer getOrganizeType() {
        String token = jwtTokenUtil.getToken();
        return jwtUtil.getOrganizeType(token);
    }

    @Override
    public Long getOrganizeId() {
        String token = jwtTokenUtil.getToken();
        return jwtUtil.getOrganizeId(token);
    }

    @Override
    public String getRegionId(String oldRegionId) {
        String token = jwtTokenUtil.getToken();
        String regionId = "";

        if(StringUtil.isEmpty(oldRegionId)){
            regionId = jwtUtil.getRegionId(token);
            if(OrganizeTypeEnum.ORGANIZE_MANAGE.getCode().equals(getOrganizeType())){
                regionId = CommonConstant.REGION_ROOT_CODE;
            }
            if(regionId.endsWith("0000")){
                regionId = regionId.substring(0,2);
            }
        }else{
            if(OrganizeTypeEnum.ORGANIZE_MANAGE.getCode().equals(getOrganizeType())||
                    OrganizeTypeEnum.ORGANIZE_CITY.getCode().equals(getOrganizeType())){
                regionId = oldRegionId;
                if(regionId.endsWith("0000")){
                    regionId = regionId.substring(0,2);
                }
            }else {
                regionId = jwtUtil.getRegionId(token);
            }
        }
        return regionId;
    }





    @Override
    public boolean verifyUserPermission(Long userId) {
        boolean passageFlag = false;
        if (getUserId().equals(userId)) {
            passageFlag = true;
        }
        return passageFlag;
    }

    @Override
    public boolean verifyOrganizePermission(Long organizeId) {
        boolean passageFlag = false;
        if (getOrganizeId() == organizeId || (getUserId() == 1 && getOrganizeId() == 1)) {
            passageFlag = true;
        }
        return passageFlag;
    }





}
