package com.xdf.creative.module.controller;


import com.xdf.creative.enums.ApiCode;
import com.xdf.creative.enums.ServiceFileUploadTypeEnum;
import com.xdf.creative.enums.StatusCode;
import com.xdf.creative.module.entity.FileUploadQuery;
import com.xdf.creative.module.service.FileClientService;
import com.xdf.creative.util.StringUtil;
import com.xdf.creative.util.UUIDUtil;
import com.xdf.creative.util.file.ServerUploadDirUtil;
import com.xdf.creative.util.file.UploadUtil;
import com.xdf.creative.util.image.FileToBase64;
import com.xdf.creative.util.page.ApiResult;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

@Slf4j
@RestController
@RequestMapping("/upload")
public class FileUploadController {

    @Value("${upload_basePath}")
    private String basePath;

    @Autowired
    private FileClientService fileClientService;

    /**
     * 上传文件
     *
     * @param file
     * @param uploadPath
     * @return
     * @throws Exception
     */
    @PostMapping("/doFile")
    @ApiOperation(value = "添加MultipartFile对象", notes = "添加文件上传", response = ApiResult.class)
    public ApiResult<String> doFile(MultipartFile file, @RequestParam Integer uploadPath) throws Exception {
        String finalPath = ServerUploadDirUtil.getFileUploadDir(uploadPath);
        ApiResult result = UploadUtil.upload(basePath + "/" + finalPath, file, ServiceFileUploadTypeEnum.SERVICE_FILE_UPLOAD_TYPE_FILE.getCode());
        if (result.getCode() == ApiCode.SUCCESS.getCode()) {
            String saveName = result.getData().toString();
            return result.ok(finalPath + "/" + saveName);
        } else {
            return result;
        }
    }

    @PostMapping("/doApplyFile")
    @ApiOperation(value = "添加MultipartFile对象", notes = "添加文件上传", response = ApiResult.class)
    public ApiResult<String> doApplyFile(MultipartFile file, @RequestParam Integer uploadPath) throws Exception {
        String finalPath = ServerUploadDirUtil.getFileUploadDir(uploadPath);
        ApiResult result = UploadUtil.upload(basePath + "/" + finalPath, file, ServiceFileUploadTypeEnum.SERVICE_FILE_UPLOAD_TYPE_FILE.getCode());
        if (result.getCode() == ApiCode.SUCCESS.getCode()) {
            String saveName = result.getData().toString();
            return result.ok(finalPath + "/" + saveName);
        } else {
            return result;
        }
    }

  /*  @PostMapping("/doExcelFile")
    @ApiOperation(value = "添加MultipartFile对象", notes = "添加文件上传", response = ApiResult.class)
    public ApiResult<String> doExcelFile(MultipartFile file, @RequestParam Integer uploadPath) throws Exception {

        //检测excel是否符合要求
        ApiResult rs = ExcelUtil.importExcel(file);
        if (ApiCode.SUCCESS.getCode() != rs.getCode()) {
            return rs;
        }

        String finalPath = ServerUploadDirUtil.getFileUploadDir(uploadPath);
        ApiResult result = UploadUtil.upload(basePath + "/" + finalPath, file, ServiceFileUploadTypeEnum.SERVICE_FILE_UPLOAD_TYPE_FILE.getCode());
        if (result.getCode() == ApiCode.SUCCESS.getCode()) {
            String saveName = result.getData().toString();
            return result.ok(finalPath + "/" + saveName);
        } else {
            return result;
        }
    }*/

    /**
     * 上传图片文件
     *
     * @param file
     * @param uploadPath
     * @return
     * @throws Exception
     */
    @PostMapping("/doPictureFile")
    @ApiOperation(value = "添加MultipartFile对象", notes = "添加图片上传", response = ApiResult.class)
    public ApiResult<String> doPictureFile(MultipartFile file, @RequestParam Integer uploadPath) throws Exception {
        String finalPath = ServerUploadDirUtil.getFileUploadDir(uploadPath);
        ApiResult result = UploadUtil.upload(basePath + "/" + finalPath, file, ServiceFileUploadTypeEnum.SERVICE_FILE_UPLOAD_TYPE_PNG.getCode());
        if (result.getCode() == ApiCode.SUCCESS.getCode()) {
            String saveName = result.getData().toString();
            return result.ok(finalPath + "/" + saveName);
        } else {
            return result;
        }
    }

    /**
     * 上传二进制文件
     *
     * @param fileUploadQuery
     * @return
     */
    @RequestMapping(value = "/uploadByDecoder")
    public ApiResult uploadFile(@RequestBody FileUploadQuery fileUploadQuery) {
        try {
            String finalPath = ServerUploadDirUtil.getFileUploadDir(fileUploadQuery.getDirType());
            fileUploadQuery.setUploadPath(finalPath);
            return fileClientService.uploadUtilFileByDecoder(fileUploadQuery, basePath);
        } catch (Exception e) {
            return ApiResult.error(StatusCode.FILE_CL_UPLOAD_FAILED);
        }
    }


    @RequestMapping(value = "/getFileByte")
    public ApiResult getFileByte(@RequestBody FileUploadQuery fileUploadQuery) {
        try {
            String uploadPath = fileUploadQuery.getUploadPath();
            if (StringUtil.isEmpty(uploadPath)) {
                return ApiResult.fail("图片地址不能为空！");
            }
            String encode = FileToBase64.encodeBase64File(basePath + uploadPath);
            return ApiResult.ok(encode);
        } catch (Exception e) {
            return ApiResult.fail("文件读取失败！");
        }
    }


    /**
     * 获取随机ID
     */
    @PostMapping("/findRandomId")
    public ApiResult findRandomId() {
        return ApiResult.ok(UUIDUtil.getUUID());
    }


}
