package com.xdf.creative.module.controller;

import com.xdf.creative.base.controller.BaseController;
import com.xdf.creative.base.params.IdParam;
import com.xdf.creative.base.params.creative.InfoAttachmentQueryParam;
import com.xdf.creative.base.vo.creative.InfoAttachmentQueryVo;
import com.xdf.creative.module.entity.InfoAttachment;
import com.xdf.creative.module.service.InfoAttachmentService;
import com.xdf.creative.util.page.ApiResult;
import com.xdf.creative.util.page.PageTool;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.Valid;

/**
 * <p>
 * 相关附件表 前端控制器
 * </p>
 *
 * @author lgw
 * @since 2020-03-09
 */
@Slf4j
@RestController
@RequestMapping("/infoAttachment")
@Api("相关附件表 API")
public class InfoAttachmentController extends BaseController {

    @Autowired
    private InfoAttachmentService infoAttachmentService;

    /**
     * 添加相关附件表
     */
    @PostMapping("/add")
    @ApiOperation(value = "添加InfoAttachment对象", notes = "添加相关附件表", response = ApiResult.class)
    public ApiResult<Boolean> addInfoAttachment(@Valid @RequestBody InfoAttachment infoAttachment) throws Exception {
        boolean flag = infoAttachmentService.save(infoAttachment);
        return ApiResult.result(flag);
    }

    /**
     * 修改相关附件表
     */
    @PostMapping("/update")
    @ApiOperation(value = "修改InfoAttachment对象", notes = "修改相关附件表", response = ApiResult.class)
    public ApiResult<Boolean> updateInfoAttachment(@Valid @RequestBody InfoAttachment infoAttachment) throws Exception {
        boolean flag = infoAttachmentService.updateById(infoAttachment);
        return ApiResult.result(flag);
    }

    /**
     * 删除相关附件表
     */
    @PostMapping("/delete")
    @ApiOperation(value = "删除InfoAttachment对象", notes = "删除相关附件表", response = ApiResult.class)
    public ApiResult<Boolean> deleteInfoAttachment(@Valid @RequestBody IdParam idParam) throws Exception {
        boolean flag = infoAttachmentService.removeById(idParam.getId());
        return ApiResult.result(flag);
    }

    /**
     * 获取相关附件表
     */
    @PostMapping("/info")
    @ApiOperation(value = "获取InfoAttachment对象详情", notes = "查看相关附件表", response = InfoAttachmentQueryVo.class)
    public ApiResult<InfoAttachmentQueryVo> getInfoAttachment(@Valid @RequestBody IdParam idParam) throws Exception {
        InfoAttachmentQueryVo infoAttachmentQueryVo = infoAttachmentService.getInfoAttachmentById(idParam.getId());
        return ApiResult.ok(infoAttachmentQueryVo);
    }

    /**
     * 相关附件表分页列表
     */
    @PostMapping("/getPageList")
    @ApiOperation(value = "获取InfoAttachment分页列表", notes = "相关附件表分页列表", response = InfoAttachmentQueryVo.class)
    public ApiResult<PageTool<InfoAttachmentQueryVo>> getInfoAttachmentPageList(@Valid @RequestBody InfoAttachmentQueryParam infoAttachmentQueryParam) throws Exception {
        PageTool<InfoAttachmentQueryVo> pageList = infoAttachmentService.getInfoAttachmentPageList(infoAttachmentQueryParam);
        return ApiResult.ok(pageList);
    }

}

