package com.xdf.creative.module.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.xdf.creative.base.controller.BaseController;
import com.xdf.creative.base.params.IdParam;
import com.xdf.creative.base.params.creative.InfoBackQueryParam;
import com.xdf.creative.base.vo.creative.InfoBackQueryVo;
import com.xdf.creative.module.entity.InfoBack;
import com.xdf.creative.module.service.InfoBackService;
import com.xdf.creative.util.page.ApiResult;
import com.xdf.creative.util.page.PageTool;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.Valid;
import java.util.List;

/**
 * <p>
 * 信息退回 前端控制器
 * </p>
 *
 * @author lgw
 * @since 2020-03-09
 */
@Slf4j
@RestController
@RequestMapping("/infoBack")
@Api("信息退回 API")
public class InfoBackController extends BaseController {

    @Autowired
    private InfoBackService infoBackService;


    /**
     * 获取信息最新退回信息
     */
    @PostMapping("/getInfoBack")
    @ApiOperation(value = "获取InfoBack对象详情", notes = "查看信息退回", response = InfoBackQueryVo.class)
    public ApiResult getInfoBack(@Valid @RequestBody IdParam idParam) throws Exception {
        List<InfoBack> infoBackList = infoBackService.list(new QueryWrapper<InfoBack>(). eq("info_id",idParam.getId()).orderByDesc("back_time"));
        if(infoBackList.size()>0){
            return ApiResult.ok(infoBackList.get(0));
        }else{
            return ApiResult.ok();
        }
    }


    /**
     * 添加信息退回
     */
    @PostMapping("/add")
    @ApiOperation(value = "添加InfoBack对象", notes = "添加信息退回", response = ApiResult.class)
    public ApiResult<Boolean> addInfoBack(@Valid @RequestBody InfoBack infoBack) throws Exception {
        boolean flag = infoBackService.save(infoBack);
        return ApiResult.result(flag);
    }

    /**
     * 修改信息退回
     */
    @PostMapping("/update")
    @ApiOperation(value = "修改InfoBack对象", notes = "修改信息退回", response = ApiResult.class)
    public ApiResult<Boolean> updateInfoBack(@Valid @RequestBody InfoBack infoBack) throws Exception {
        boolean flag = infoBackService.updateById(infoBack);
        return ApiResult.result(flag);
    }

    /**
     * 删除信息退回
     */
    @PostMapping("/delete")
    @ApiOperation(value = "删除InfoBack对象", notes = "删除信息退回", response = ApiResult.class)
    public ApiResult<Boolean> deleteInfoBack(@Valid @RequestBody IdParam idParam) throws Exception {
        boolean flag = infoBackService.removeById(idParam.getId());
        return ApiResult.result(flag);
    }

    /**
     * 获取信息退回
     */
    @PostMapping("/info")
    @ApiOperation(value = "获取InfoBack对象详情", notes = "查看信息退回", response = InfoBackQueryVo.class)
    public ApiResult<InfoBackQueryVo> info(@Valid @RequestBody IdParam idParam) throws Exception {
        InfoBackQueryVo infoBackQueryVo = infoBackService.getInfoBackById(idParam.getId());
        return ApiResult.ok(infoBackQueryVo);
    }

    /**
     * 信息退回分页列表
     */
    @PostMapping("/getPageList")
    @ApiOperation(value = "获取InfoBack分页列表", notes = "信息退回分页列表", response = InfoBackQueryVo.class)
    public ApiResult<PageTool<InfoBackQueryVo>> getInfoBackPageList(@Valid @RequestBody InfoBackQueryParam infoBackQueryParam) throws Exception {
        PageTool<InfoBackQueryVo> pageList = infoBackService.getInfoBackPageList(infoBackQueryParam);
        return ApiResult.ok(pageList);
    }

}

