package com.xdf.creative.module.controller;

import com.xdf.creative.base.controller.BaseController;
import com.xdf.creative.base.params.IdParam;
import com.xdf.creative.base.params.creative.*;
import com.xdf.creative.base.vo.creative.*;
import com.xdf.creative.module.entity.InfoContent;
import com.xdf.creative.module.service.InfoContentService;
import com.xdf.creative.support.aop.OperateLogger;
import com.xdf.creative.util.page.ApiResult;
import com.xdf.creative.util.page.PageTool;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import java.util.List;

/**
 * <p>
 * 信息内容 前端控制器
 * </p>
 *
 * @author lgw
 * @since 2020-03-09
 */
@Slf4j
@RestController
@RequestMapping("/infoContent")
@Api("信息内容 API")
public class InfoContentController extends BaseController {

    @Autowired
    private InfoContentService infoContentService;

    /**
     * 添加信息内容
     */
    @PostMapping("/addInfoContent")
    @ApiOperation(value = "添加InfoContent对象", notes = "添加信息内容", response = ApiResult.class)
    @OperateLogger(name = "添加内容", attributeId = "id", attributeName = "title")
    public ApiResult addInfoContent(@Valid @RequestBody InfoContentAddQueryParam infoContentAddQueryParam) throws Exception {
        return infoContentService.addInfoContent(infoContentAddQueryParam);
    }

    /**
     * 预览 web查看详情
     */
    @PostMapping("/getWebInfoContent")
    @ApiOperation(value = "获取单条InfoContent对象", notes = "获取单条信息内容", response = ApiResult.class)
    public ApiResult getWebInfoContent(@Valid @RequestBody IdParam idParam) throws Exception {
        return infoContentService.getWebInfoContent(idParam.getId());
    }

    /**
     * 获取信息内容
     */
    @PostMapping("/getInfoContent")
    @ApiOperation(value = "获取单条InfoContent对象", notes = "获取单条信息内容", response = ApiResult.class)
    public ApiResult getInfoContent(@Valid @RequestBody IdParam idParam) throws Exception {
        return infoContentService.getInfoContent(idParam.getId());
    }

    /**
     * 修改信息内容
     *
     * @param infoContentAddQueryParam
     * @return
     * @throws Exception
     */
    @PostMapping("/updateInfoContent")
    @ApiOperation(value = "修改InfoContent对象", notes = "修改信息内容", response = ApiResult.class)
    @OperateLogger(name = "修改内容", attributeId = "id", attributeName = "title")
    public ApiResult updateInfoContent(@Valid @RequestBody InfoContentAddQueryParam infoContentAddQueryParam) throws Exception {
        return infoContentService.updateInfoContent(infoContentAddQueryParam);
    }



    @PostMapping("/editInfoManage")
    @ApiOperation(value = "修改InfoContent对象", notes = "修改信息内容", response = ApiResult.class)
    @OperateLogger(name = "管理员修改内容", attributeId = "id", attributeName = "title")
    public ApiResult editInfoManage(@Valid @RequestBody InfoContentEditQueryParam infoContentEditQueryParam) throws Exception {
        return infoContentService.editInfoManage(infoContentEditQueryParam);
    }

    /**
     * 管理员初审信息
     *
     * @param infoContentAuditQueryParam
     * @return
     * @throws Exception
     */
    @PostMapping("/firstAuditInfo")
    @ApiOperation(value = "初审InfoContent对象", notes = "初审信息内容", response = ApiResult.class)
    @OperateLogger(name = "初审内容", attributeId = "id", attributeName = "title")
    public ApiResult firstAuditInfo(@Valid @RequestBody InfoContentAuditQueryParam infoContentAuditQueryParam) throws Exception {
        return infoContentService.firstAuditInfo(infoContentAuditQueryParam);
    }

    /**
     * 管理员终审信息
     *
     * @param infoContentAuditQueryParam
     * @return
     * @throws Exception
     */
    @PostMapping("/finalAuditInfo")
    @ApiOperation(value = "终审InfoContent对象", notes = "终审信息内容", response = ApiResult.class)
    @OperateLogger(name = "终审内容", attributeId = "id", attributeName = "title")
    public ApiResult finalAuditInfo(@Valid @RequestBody InfoContentAuditQueryParam infoContentAuditQueryParam) throws Exception {
        return infoContentService.finalAuditInfo(infoContentAuditQueryParam);
    }


    /**
     * 用户提交信息内容
     *
     * @param infoContentAuditQueryParam
     * @return
     * @throws Exception
     */
    @PostMapping("/commitInfoContent")
    @ApiOperation(value = "提交InfoContent对象", notes = "提交信息内容", response = ApiResult.class)
    @OperateLogger(name = "提交内容", attributeId = "id", attributeName = "title")
    public ApiResult commitInfoContent(@Valid @RequestBody InfoContentAuditQueryParam infoContentAuditQueryParam) throws Exception {
        return infoContentService.commitInfoContent(infoContentAuditQueryParam);
    }

    /**
     * 上下线信息内容
     *
     * @param infoContentAuditQueryParam
     * @return
     * @throws Exception
     */
    @PostMapping("/onlineInfoContent")
    @ApiOperation(value = "上下线InfoContent对象", notes = "上下线信息内容", response = ApiResult.class)
    @OperateLogger(name = "上下线内容", attributeId = "id", attributeName = "title")
    public ApiResult onlineInfoContent(@Valid @RequestBody InfoContentAuditQueryParam infoContentAuditQueryParam) throws Exception {
        return infoContentService.onlineInfoContent(infoContentAuditQueryParam);
    }


    /**
     * 是否置顶信息内容
     *
     * @param infoContentAuditQueryParam
     * @return
     * @throws Exception
     */
    @PostMapping("/isTopInfoContent")
    @ApiOperation(value = "置顶InfoContent对象", notes = "置顶信息内容", response = ApiResult.class)
    @OperateLogger(name = "置顶内容", attributeId = "id", attributeName = "title")
    public ApiResult isTopInfoContent(@Valid @RequestBody InfoContentAuditQueryParam infoContentAuditQueryParam) throws Exception {
        return infoContentService.isTopInfoContent(infoContentAuditQueryParam);
    }

    /**
     * 修改排序号
     *
     * @param infoContentAuditQueryParam
     * @return
     * @throws Exception
     */
    @PostMapping("/updateInfoSort")
    @ApiOperation(value = "修改排序号InfoContent对象", notes = "修改信息内容排序号", response = ApiResult.class)
    @OperateLogger(name = "修改内容排序", attributeId = "id", attributeName = "title")
    public ApiResult updateInfoSort(@Valid @RequestBody InfoContentAuditQueryParam infoContentAuditQueryParam) throws Exception {
        return infoContentService.updateInfoSort(infoContentAuditQueryParam);
    }

    /**
     * 信息是否置为回收站
     *
     * @param infoContentAuditQueryParam
     * @return
     * @throws Exception
     */
    @PostMapping("/recycleInfoContent")
    @ApiOperation(value = "将InfoContent对象置为回收站", notes = "将信息内容置为回收站", response = ApiResult.class)
    @OperateLogger(name = "删除/还原内容（回收站）", attributeId = "id", attributeName = "title")
    public ApiResult recycleInfoContent(@Valid @RequestBody InfoContentAuditQueryParam infoContentAuditQueryParam) throws Exception {
        return infoContentService.recycleInfoContent(infoContentAuditQueryParam);
    }

    /**
     * 信息管理员删除（任何状态可以删除）
     *
     * @param infoContentAuditQueryParam
     * @return
     * @throws Exception
     */
    @PostMapping("/deleteInfoManageContent")
    @ApiOperation(value = "删除InfoContent对象", notes = "删除信息内容", response = ApiResult.class)
    @OperateLogger(name = "回收站删除内容", attributeId = "id", attributeName = "title")
    public ApiResult deleteInfoManageContent(@Valid @RequestBody InfoContentAuditQueryParam infoContentAuditQueryParam) throws Exception {
        return infoContentService.deleteInfoManageContent(infoContentAuditQueryParam);
    }



    /**
     * 首页搜索信息
     */
    @PostMapping("/getSearchMbInfo")
    @ApiOperation(value = "获取InfoContentWeb分页列表", notes = "信息内容分页列表", response = InfoContentWebSearchMbQueryVo.class)
    public ApiResult<PageTool<InfoContentWebSearchMbQueryVo>> getSearchMbInfo(@Valid @RequestBody InfoContentWebSearchQueryParam infoContentWebSearchQueryParam) throws Exception {
        PageTool<InfoContentWebSearchMbQueryVo> pageList = infoContentService.getSearchMbInfo(infoContentWebSearchQueryParam);
        return ApiResult.ok(pageList);
    }


    /**
     * 首页查询信息
     */
    @PostMapping("/getHomePageInfo")
    @ApiOperation(value = "显示InfoContent对象", notes = "首页查询信息", response = ApiResult.class)
    public ApiResult getHomePageInfo(@Valid @RequestBody InfoContentHomePageQueryParam infoContentHomePageQueryParam) throws Exception {
        return infoContentService.getHomePageInfo(infoContentHomePageQueryParam);
    }


    /**
     * 首页查询信息
     */
    @PostMapping("/getHomePagesInfo")
    @ApiOperation(value = "显示InfoContent对象", notes = "首页查询信息", response = ApiResult.class)
    public ApiResult getHomePagesInfo(@Valid @RequestBody InfoContentHomePageListParam infoContentHomePageListParam) throws Exception {
        return infoContentService.getHomePagesInfo(infoContentHomePageListParam);
    }


    /**
     * 首页搜索信息
     */
    @PostMapping("/getSearchWebInfo")
    @ApiOperation(value = "获取InfoContentWeb分页列表", notes = "信息内容分页列表", response = InfoContentWebSearchQueryVo.class)
    public ApiResult<PageTool<InfoContentWebSearchQueryVo>> getSearchWebInfo(@Valid @RequestBody InfoContentWebSearchQueryParam infoContentWebSearchQueryParam) throws Exception {
        PageTool<InfoContentWebSearchQueryVo> pageList = infoContentService.getSearchWebInfo(infoContentWebSearchQueryParam);
        return ApiResult.ok(pageList);
    }


    @GetMapping("/getSearchParkRecommendWebInfo")
    @ApiOperation(value = "获取InfoContentWeb分页列表", notes = "信息内容分页列表", response = InfoContentWebSearchQueryVo.class)
    public ApiResult<List<InfoContentWebSearchQueryVo>> getSearchParkRecommendWebInfo() throws Exception {
        InfoContentWebSearchQueryParam infoContentWebSearchQueryParam = new InfoContentWebSearchQueryParam();
        infoContentWebSearchQueryParam.setTitle("文化");
        return ApiResult.ok(infoContentService.getSearchParkRecommendWebInfo(infoContentWebSearchQueryParam));
    }




    @PostMapping("/getSearchWebsInfo")
    @ApiOperation(value = "获取InfoContentWeb分页列表", notes = "信息内容分页列表", response = InfoContentWebSearchQueryVo.class)
    public ApiResult<PageTool<InfoContentWebSearchQueryVo>> getSearchWebsInfo(@Valid @RequestBody InfoContentWebSearchListParam infoContentWebSearchListParam) throws Exception {
        PageTool<InfoContentWebSearchQueryVo> pageList = infoContentService.getSearchWebsInfo(infoContentWebSearchListParam);
        return ApiResult.ok(pageList);
    }


    /**
     * 后台发布列表
     */
    @PostMapping("/getInfoContentByAdd")
    @ApiOperation(value = "获取InfoContentBackSearchQueryVo分页列表", notes = "后台发布列表", response = InfoContentWebSearchQueryVo.class)
    public ApiResult<PageTool<InfoContentBackSearchQueryVo>> getInfoContentByAdd(@Valid @RequestBody InfoContentBackSearchQueryParam infoContentBackSearchQueryParam) throws Exception {
        PageTool<InfoContentBackSearchQueryVo> pageList = infoContentService.getInfoContentByAdd(infoContentBackSearchQueryParam);
        return ApiResult.ok(pageList);
    }

    /**
     * 后台初审列表
     */
    @PostMapping("/getInfoContentByFirstAudit")
    @ApiOperation(value = "获取InfoContentBackSearchQueryVo分页列表", notes = "后台发布列表", response = InfoContentBackSearchQueryVo.class)
    public ApiResult<PageTool<InfoContentBackSearchQueryVo>> getInfoContentByFirstAudit(@Valid @RequestBody InfoContentBackSearchQueryParam infoContentBackSearchQueryParam) throws Exception {
        PageTool<InfoContentBackSearchQueryVo> pageList = infoContentService.getInfoContentByFirstAudit(infoContentBackSearchQueryParam);
        return ApiResult.ok(pageList);
    }

    /**
     * 后台初审列表
     */
    @PostMapping("/getInfoContentByFinalAudit")
    @ApiOperation(value = "获取InfoContentBackSearchQueryVo分页列表", notes = "后台发布列表", response = InfoContentBackSearchQueryVo.class)
    public ApiResult<PageTool<InfoContentBackSearchQueryVo>> getInfoContentByFinalAudit(@Valid @RequestBody InfoContentBackSearchQueryParam infoContentBackSearchQueryParam) throws Exception {
        PageTool<InfoContentBackSearchQueryVo> pageList = infoContentService.getInfoContentByFinalAudit(infoContentBackSearchQueryParam);
        return ApiResult.ok(pageList);
    }

    /**
     * 后台回收站列表
     */
    @PostMapping("/getInfoContentByRecycle")
    @ApiOperation(value = "获取InfoContentRecycleSearchQueryVo分页列表", notes = "后台回收站列表", response = InfoContentRecycleSearchQueryVo.class)
    public ApiResult<PageTool<InfoContentRecycleSearchQueryVo>> getInfoContentByRecycle(@Valid @RequestBody InfoContentBackSearchQueryParam infoContentBackSearchQueryParam) throws Exception {
        PageTool<InfoContentRecycleSearchQueryVo> pageList = infoContentService.getInfoContentByRecycle(infoContentBackSearchQueryParam);
        return ApiResult.ok(pageList);
    }


    /**
     * 修改信息内容
     */
    @PostMapping("/update")
    @ApiOperation(value = "修改InfoContent对象", notes = "修改信息内容", response = ApiResult.class)
    public ApiResult<Boolean> updateInfoContent(@Valid @RequestBody InfoContent infoContent) throws Exception {
        boolean flag = infoContentService.updateById(infoContent);
        return ApiResult.result(flag);
    }

    /**
     * 删除信息内容
     */
    @PostMapping("/delete")
    @ApiOperation(value = "删除InfoContent对象", notes = "删除信息内容", response = ApiResult.class)
    public ApiResult<Boolean> deleteInfoContent(@Valid @RequestBody IdParam idParam) throws Exception {
        boolean flag = infoContentService.removeById(idParam.getId());
        return ApiResult.result(flag);
    }



    @PostMapping("/getInfoHtml")
    @ApiOperation(value = "删除InfoContent对象", notes = "删除信息内容", response = ApiResult.class)
    public ApiResult getInfoHtml(@RequestBody IdParam idParam) throws Exception {
        return infoContentService.getInfoHtml(idParam.getValue());
    }

    /**
     * @description: 初始化超链接新闻爬取
     * @param:
     * @return: com.xdf.creative.util.page.ApiResult
     * @author  一路心飞扬 lgw
     * @date: 2020/12/25 14:08
     */
    @GetMapping("/getHtmlByInfo")
    @ApiOperation(value = "删除InfoContent对象", notes = "删除信息内容", response = ApiResult.class)
    public ApiResult getHtmlByInfo()  {
        return infoContentService.getHtmlByInfo();
    }



    /**
     * 信息内容分页列表
     */
    @PostMapping("/getPageList")
    @ApiOperation(value = "获取InfoContent分页列表", notes = "信息内容分页列表", response = InfoContentQueryVo.class)
    public ApiResult<PageTool<InfoContentQueryVo>> getInfoContentPageList(@Valid @RequestBody InfoContentQueryParam infoContentQueryParam) throws Exception {
        PageTool<InfoContentQueryVo> pageList = infoContentService.getInfoContentPageList(infoContentQueryParam);
        return ApiResult.ok(pageList);
    }

}

