package com.xdf.creative.module.controller;

import com.xdf.creative.base.controller.BaseController;
import com.xdf.creative.base.params.IdParam;
import com.xdf.creative.base.params.creative.InfoKeywordAddParam;
import com.xdf.creative.base.params.creative.InfoKeywordQueryParam;
import com.xdf.creative.base.params.creative.InfoKeywordSaveCheckParam;
import com.xdf.creative.base.vo.creative.InfoKeywordQueryVo;
import com.xdf.creative.module.service.InfoKeywordService;
import com.xdf.creative.util.page.ApiResult;
import com.xdf.creative.util.page.PageTool;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.Valid;

/**
 * <p>
 * 信息关键字 前端控制器
 * </p>
 *
 * @author lgw
 * @since 2020-11-27
 */
@Slf4j
@RestController
@RequestMapping("/infoKeyword")
@Api("信息关键字 API")
public class InfoKeywordController extends BaseController {

    @Autowired
    private InfoKeywordService infoKeywordService;

    /**
     * 添加信息关键字
     */
    @PostMapping("/add")
    @ApiOperation(value = "添加InfoKeyword对象", notes = "添加信息关键字", response = ApiResult.class)
    public ApiResult addInfoKeyword(@Valid @RequestBody InfoKeywordAddParam infoKeywordAddParam) throws Exception {
        return infoKeywordService.add(infoKeywordAddParam);
    }

    /**
     * 删除信息
     * @param idParam
     * @return
     * @throws Exception
     */
    @PostMapping("/del")
    @ApiOperation(value = "删除关键词", notes = "删除关键词", response = ApiResult.class)
    public ApiResult del(@Valid @RequestBody IdParam idParam) throws Exception {
        return infoKeywordService.del(idParam.getId());
    }

    /**
     * 修改信息关键字
     */
    @PostMapping("/edit")
    @ApiOperation(value = "修改InfoKeyword对象", notes = "修改信息关键字", response = ApiResult.class)
    public ApiResult edit(@Valid @RequestBody InfoKeywordAddParam infoKeywordAddParam) throws Exception {
        return infoKeywordService.edit(infoKeywordAddParam);
    }


    /**
     * 保存已选择的信息列表
     * @param infoKeywordSaveCheckParam
     * @return
     * @throws Exception
     */
    @PostMapping("/saveCheckList")
    @ApiOperation(value = "修改InfoKeyword对象", notes = "修改信息关键字", response = ApiResult.class)
    public ApiResult saveCheckList(@Valid @RequestBody InfoKeywordSaveCheckParam infoKeywordSaveCheckParam) throws Exception {
        return infoKeywordService.saveCheckList(infoKeywordSaveCheckParam);
    }


    /**
     * 启用停用关键字
     * @param idParam
     * @return
     * @throws Exception
     */
    @PostMapping("/enable")
    @ApiOperation(value = "启用停用", notes = "删除信息关键字", response = ApiResult.class)
    public ApiResult enable(@Valid @RequestBody IdParam idParam) throws Exception {
        return infoKeywordService.enable(idParam.getId());
    }

    /**
     * 获取已选择的关键字列表
     * @param idParam
     * @return
     * @throws Exception
     */
    @PostMapping("/getCheckList")
    @ApiOperation(value = "启用停用", notes = "删除信息关键字", response = ApiResult.class)
    public ApiResult getCheckList(@Valid @RequestBody IdParam idParam) throws Exception {
        return infoKeywordService.getCheckList(idParam.getId());
    }



    /**
     * 删除信息关键字
     */
    @PostMapping("/delete")
    @ApiOperation(value = "删除InfoKeyword对象", notes = "删除信息关键字", response = ApiResult.class)
    public ApiResult<Boolean> deleteInfoKeyword(@Valid @RequestBody IdParam idParam) throws Exception {
        boolean flag = infoKeywordService.removeById(idParam.getId());
        return ApiResult.result(flag);
    }

    /**
     * 获取信息关键字
     */
    @PostMapping("/info")
    @ApiOperation(value = "获取InfoKeyword对象详情", notes = "查看信息关键字", response = InfoKeywordQueryVo.class)
    public ApiResult<InfoKeywordQueryVo> getInfoKeyword(@Valid @RequestBody IdParam idParam) throws Exception {
        InfoKeywordQueryVo infoKeywordQueryVo = infoKeywordService.getInfoKeywordById(idParam.getId());
        return ApiResult.ok(infoKeywordQueryVo);
    }

    /**
     * 信息关键字分页列表
     */
    @PostMapping("/getPageList")
    @ApiOperation(value = "获取InfoKeyword分页列表", notes = "信息关键字分页列表", response = InfoKeywordQueryVo.class)
    public ApiResult<PageTool<InfoKeywordQueryVo>> getInfoKeywordPageList(@Valid @RequestBody InfoKeywordQueryParam infoKeywordQueryParam) throws Exception {
        PageTool<InfoKeywordQueryVo> pageList = infoKeywordService.getInfoKeywordPageList(infoKeywordQueryParam);
        return ApiResult.ok(pageList);
    }

}

