package com.xdf.creative.module.controller;

import com.xdf.creative.base.controller.BaseController;
import com.xdf.creative.base.params.IdParam;
import com.xdf.creative.base.params.creative.InfoTypeQueryParam;
import com.xdf.creative.base.vo.creative.InfoTypeQueryVo;
import com.xdf.creative.module.entity.InfoType;
import com.xdf.creative.module.service.InfoTypeService;
import com.xdf.creative.support.aop.OperateLogger;
import com.xdf.creative.util.page.ApiResult;
import com.xdf.creative.util.page.PageTool;
import com.xdf.creative.util.tree.TreeConfig;
import com.xdf.creative.util.tree.Utils;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.Valid;
import java.util.List;

/**
 * <p>
 * 栏目类型 前端控制器
 * </p>
 *
 * @author lgw
 * @since 2020-03-06
 */
@Slf4j
@RestController
@RequestMapping("/infoType")
@Api("栏目类型 API")
public class InfoTypeController extends BaseController {

    @Autowired
    private InfoTypeService infoTypeService;

    /**
     * 添加栏目类型
     */
    @PostMapping("/addInfoType")
    @ApiOperation(value = "添加InfoType对象", notes = "添加栏目类型", response = ApiResult.class)
    @OperateLogger(name = "添加栏目类型",attributeId="id",attributeName="infoName")
    public ApiResult addInfoType(@Valid @RequestBody InfoType infoType) throws Exception {
        return  infoTypeService.addInfoType(infoType);
    }

    /**
     * 栏目类型分页列表
     */
    @PostMapping("/getPageList")
    @ApiOperation(value = "获取InfoType分页列表", notes = "栏目类型分页列表", response = InfoTypeQueryVo.class)
    public ApiResult<PageTool<InfoTypeQueryVo>> getInfoTypePageList(@Valid @RequestBody InfoTypeQueryParam infoTypeQueryParam) throws Exception {
        PageTool<InfoTypeQueryVo> pageList = infoTypeService.getInfoTypePageList(infoTypeQueryParam);
        return ApiResult.ok(pageList);
    }



    /**
     * 栏目类型Tree列表
     */
    @PostMapping("/getInfoTypeTreeList")
    @ApiOperation(value = "获取栏目类型Tree列表", notes = "栏目类型Tree列表", response = InfoTypeQueryVo.class)
    public ApiResult getInfoTypeTreeList() throws Exception {
        List<Object> list =infoTypeService.getInfoTypeTreeList();
        TreeConfig config = new TreeConfig("typeId", "typeParentId", "typeParentId", "0", "");
        return ApiResult.ok(Utils.tree(list, config));
    }





    /**
     * 修改栏目类型
     */
    @PostMapping("/update")
    @ApiOperation(value = "修改InfoType对象", notes = "修改栏目类型", response = ApiResult.class)
    public ApiResult<Boolean> updateInfoType(@Valid @RequestBody InfoType infoType) throws Exception {
        boolean flag = infoTypeService.updateById(infoType);
        return ApiResult.result(flag);
    }

    /**
     * 删除栏目类型
     */
    @PostMapping("/delete")
    @ApiOperation(value = "删除InfoType对象", notes = "删除栏目类型", response = ApiResult.class)
    public ApiResult<Boolean> deleteInfoType(@Valid @RequestBody IdParam idParam) throws Exception {
        boolean flag = infoTypeService.removeById(idParam.getId());
        return ApiResult.result(flag);
    }

    /**
     * 获取栏目类型
     */
    @PostMapping("/info")
    @ApiOperation(value = "获取InfoType对象详情", notes = "查看栏目类型", response = InfoTypeQueryVo.class)
    public ApiResult<InfoTypeQueryVo> getInfoType(@Valid @RequestBody IdParam idParam) throws Exception {
        InfoTypeQueryVo infoTypeQueryVo = infoTypeService.getInfoTypeById(idParam.getId());
        return ApiResult.ok(infoTypeQueryVo);
    }



}

