package com.xdf.creative.module.controller;

import com.xdf.creative.base.controller.BaseController;
import com.xdf.creative.base.params.IdParam;
import com.xdf.creative.base.params.creative.InfoUrlQueryParam;
import com.xdf.creative.base.vo.creative.InfoUrlQueryVo;
import com.xdf.creative.module.entity.InfoUrl;
import com.xdf.creative.module.service.InfoUrlService;
import com.xdf.creative.util.page.ApiResult;
import com.xdf.creative.util.page.PageTool;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.Valid;

/**
 * <p>
 * 相关链接 前端控制器
 * </p>
 *
 * @author lgw
 * @since 2020-03-09
 */
@Slf4j
@RestController
@RequestMapping("/infoUrl")
@Api("相关链接 API")
public class InfoUrlController extends BaseController {

    @Autowired
    private InfoUrlService infoUrlService;

    /**
     * 添加相关链接
     */
    @PostMapping("/add")
    @ApiOperation(value = "添加InfoUrl对象", notes = "添加相关链接", response = ApiResult.class)
    public ApiResult<Boolean> addInfoUrl(@Valid @RequestBody InfoUrl infoUrl) throws Exception {
        boolean flag = infoUrlService.save(infoUrl);
        return ApiResult.result(flag);
    }

    /**
     * 修改相关链接
     */
    @PostMapping("/update")
    @ApiOperation(value = "修改InfoUrl对象", notes = "修改相关链接", response = ApiResult.class)
    public ApiResult<Boolean> updateInfoUrl(@Valid @RequestBody InfoUrl infoUrl) throws Exception {
        boolean flag = infoUrlService.updateById(infoUrl);
        return ApiResult.result(flag);
    }

    /**
     * 删除相关链接
     */
    @PostMapping("/delete")
    @ApiOperation(value = "删除InfoUrl对象", notes = "删除相关链接", response = ApiResult.class)
    public ApiResult<Boolean> deleteInfoUrl(@Valid @RequestBody IdParam idParam) throws Exception {
        boolean flag = infoUrlService.removeById(idParam.getId());
        return ApiResult.result(flag);
    }

    /**
     * 获取相关链接
     */
    @PostMapping("/info")
    @ApiOperation(value = "获取InfoUrl对象详情", notes = "查看相关链接", response = InfoUrlQueryVo.class)
    public ApiResult<InfoUrlQueryVo> getInfoUrl(@Valid @RequestBody IdParam idParam) throws Exception {
        InfoUrlQueryVo infoUrlQueryVo = infoUrlService.getInfoUrlById(idParam.getId());
        return ApiResult.ok(infoUrlQueryVo);
    }

    /**
     * 相关链接分页列表
     */
    @PostMapping("/getPageList")
    @ApiOperation(value = "获取InfoUrl分页列表", notes = "相关链接分页列表", response = InfoUrlQueryVo.class)
    public ApiResult<PageTool<InfoUrlQueryVo>> getInfoUrlPageList(@Valid @RequestBody InfoUrlQueryParam infoUrlQueryParam) throws Exception {
        PageTool<InfoUrlQueryVo> pageList = infoUrlService.getInfoUrlPageList(infoUrlQueryParam);
        return ApiResult.ok(pageList);
    }

}

