package com.xdf.creative.module.controller;

import com.xdf.creative.base.controller.BaseController;
import com.xdf.creative.base.params.IdParam;
import com.xdf.creative.base.params.creative.InfoWordManageQueryParam;
import com.xdf.creative.base.vo.creative.InfoWordManageQueryVo;
import com.xdf.creative.module.entity.InfoWordManage;
import com.xdf.creative.module.service.InfoWordManageService;
import com.xdf.creative.support.aop.OperateLogger;
import com.xdf.creative.util.page.ApiResult;
import com.xdf.creative.util.page.PageTool;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.Valid;

/**
 * <p>
 * 词管理 前端控制器
 * </p>
 *
 * @author lgw
 * @since 2020-03-06
 */
@Slf4j
@RestController
@RequestMapping("/infoWordManage")
@Api("词管理 API")
public class InfoWordManageController extends BaseController {

    @Autowired
    private InfoWordManageService infoWordManageService;

    /**
     * 添加词管理
     */
    @PostMapping("/addInfoWordManage")
    @ApiOperation(value = "添加InfoWordManage对象", notes = "添加词管理", response = ApiResult.class)
    @OperateLogger(name = "添加敏感词",attributeId="id",attributeName="word")
    public ApiResult addInfoWordManage(@Valid @RequestBody InfoWordManage infoWordManage) throws Exception {
        return infoWordManageService.addInfoWordManage(infoWordManage);
    }
    /**
     * 修改词管理
     */
    @PostMapping("/updateInfoWordManage")
    @ApiOperation(value = "修改InfoWordManage对象", notes = "修改词管理", response = ApiResult.class)
    @OperateLogger(name = "修改敏感词",attributeId="id",attributeName="word")
    public ApiResult  updateInfoWordManage(@Valid @RequestBody InfoWordManage infoWordManage) throws Exception {
        return infoWordManageService.updateInfoWordManage(infoWordManage);
    }

    /**
     * 删除词管理
     */
    @PostMapping("/deleteInfoWordManage")
    @ApiOperation(value = "删除InfoWordManage对象", notes = "删除词管理", response = ApiResult.class)
    @OperateLogger(name = "删除敏感词",attributeId="id",attributeName="value")
    public ApiResult<Boolean> deleteInfoWordManage(@Valid @RequestBody IdParam idParam) throws Exception {
        return infoWordManageService.deleteInfoWordManage(idParam);
    }

    /**
     * 词管理分页列表
     */
    @PostMapping("/getPageList")
    @ApiOperation(value = "获取InfoWordManage分页列表", notes = "词管理分页列表", response = InfoWordManageQueryVo.class)
    public ApiResult<PageTool<InfoWordManageQueryVo>> getInfoWordManagePageList(@Valid @RequestBody InfoWordManageQueryParam infoWordManageQueryParam) throws Exception {
        PageTool<InfoWordManageQueryVo> pageList = infoWordManageService.getInfoWordManagePageList(infoWordManageQueryParam);
        return ApiResult.ok(pageList);
    }




    /**
     * 获取词管理
     */
    @PostMapping("/getInfoWordManage")
    @ApiOperation(value = "获取InfoWordManage对象详情", notes = "查看词管理", response = InfoWordManageQueryVo.class)
    public ApiResult<InfoWordManageQueryVo> getInfoWordManage(@Valid @RequestBody IdParam idParam) throws Exception {
        InfoWordManageQueryVo infoWordManageQueryVo = infoWordManageService.getInfoWordManageById(idParam.getId());
        return ApiResult.ok(infoWordManageQueryVo);
    }



}

