package com.xdf.creative.module.controller;

import com.xdf.creative.base.controller.BaseController;
import com.xdf.creative.base.params.IdParam;
import com.xdf.creative.base.params.creative.OauthTokenQueryParam;
import com.xdf.creative.base.vo.creative.OauthTokenQueryVo;
import com.xdf.creative.module.entity.OauthToken;
import com.xdf.creative.module.service.OauthTokenService;
import com.xdf.creative.util.page.ApiResult;
import com.xdf.creative.util.page.PageTool;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.Valid;

/**
 * <p>
 * 前端控制器
 * </p>
 *
 * @author lgw
 * @since 2020-03-05
 */
@Slf4j
@RestController
@RequestMapping("/oauthToken")
@Api(" API")
public class OauthTokenController extends BaseController {

    @Autowired
    private OauthTokenService oauthTokenService;

    /**
     * 添加
     */
    @PostMapping("/add")
    @ApiOperation(value = "添加OauthToken对象", notes = "添加", response = ApiResult.class)
    public ApiResult<Boolean> addOauthToken(@Valid @RequestBody OauthToken oauthToken) throws Exception {
        boolean flag = oauthTokenService.save(oauthToken);
        return ApiResult.result(flag);
    }

    /**
     * 修改
     */
    @PostMapping("/update")
    @ApiOperation(value = "修改OauthToken对象", notes = "修改", response = ApiResult.class)
    public ApiResult<Boolean> updateOauthToken(@Valid @RequestBody OauthToken oauthToken) throws Exception {
        boolean flag = oauthTokenService.updateById(oauthToken);
        return ApiResult.result(flag);
    }

    /**
     * 删除
     */
    @PostMapping("/delete")
    @ApiOperation(value = "删除OauthToken对象", notes = "删除", response = ApiResult.class)
    public ApiResult<Boolean> deleteOauthToken(@Valid @RequestBody IdParam idParam) throws Exception {
        boolean flag = oauthTokenService.removeById(idParam.getId());
        return ApiResult.result(flag);
    }

    /**
     * 获取
     */
    @PostMapping("/info")
    @ApiOperation(value = "获取OauthToken对象详情", notes = "查看", response = OauthTokenQueryVo.class)
    public ApiResult<OauthTokenQueryVo> getOauthToken(@Valid @RequestBody IdParam idParam) throws Exception {
        OauthTokenQueryVo oauthTokenQueryVo = oauthTokenService.getOauthTokenById(idParam.getId());
        return ApiResult.ok(oauthTokenQueryVo);
    }

    /**
     * 分页列表
     */
    @PostMapping("/getPageList")
    @ApiOperation(value = "获取OauthToken分页列表", notes = "分页列表", response = OauthTokenQueryVo.class)
    public ApiResult<PageTool<OauthTokenQueryVo>> getOauthTokenPageList(@Valid @RequestBody OauthTokenQueryParam oauthTokenQueryParam) throws Exception {
        PageTool<OauthTokenQueryVo> pageList = oauthTokenService.getOauthTokenPageList(oauthTokenQueryParam);
        return ApiResult.ok(pageList);
    }

}

