package com.xdf.creative.module.controller;

import com.xdf.creative.base.controller.BaseController;
import com.xdf.creative.base.params.IdParam;
import com.xdf.creative.base.params.creative.SysAccountLogQueryParam;
import com.xdf.creative.base.vo.creative.SysAccountLogQueryVo;
import com.xdf.creative.module.entity.SysAccountLog;
import com.xdf.creative.module.service.SysAccountLogService;
import com.xdf.creative.util.page.ApiResult;
import com.xdf.creative.util.page.PageTool;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.Valid;

/**
 * <p>
 * 账户登录日志 前端控制器
 * </p>
 *
 * @author lgw
 * @since 2020-03-06
 */
@Slf4j
@RestController
@RequestMapping("/sysAccountLog")
@Api("账户登录日志 API")
public class SysAccountLogController extends BaseController {

    @Autowired
    private SysAccountLogService sysAccountLogService;

    /**
     * 账户登录日志分页列表
     */
    @PostMapping("/getPageList")
    @ApiOperation(value = "获取SysAccountLog分页列表", notes = "账户登录日志分页列表", response = SysAccountLogQueryVo.class)
    public ApiResult<PageTool<SysAccountLogQueryVo>> getSysAccountLogPageList(@Valid @RequestBody SysAccountLogQueryParam sysAccountLogQueryParam) throws Exception {
        PageTool<SysAccountLogQueryVo> pageList = sysAccountLogService.getSysAccountLogPageList(sysAccountLogQueryParam);
        return ApiResult.ok(pageList);
    }

    /**
     * 删除账户登录日志
     */
    @PostMapping("/deleteSysAccountLog")
    @ApiOperation(value = "删除SysAccountLog对象", notes = "删除账户登录日志", response = ApiResult.class)
    public ApiResult<Boolean> deleteSysAccountLog(@Valid @RequestBody IdParam idParam) throws Exception {
        boolean flag = sysAccountLogService.removeById(idParam.getId());
        return ApiResult.result(flag);
    }




    /**
     * 添加账户登录日志
     */
    @PostMapping("/add")
    @ApiOperation(value = "添加SysAccountLog对象", notes = "添加账户登录日志", response = ApiResult.class)
    public ApiResult<Boolean> addSysAccountLog(@Valid @RequestBody SysAccountLog sysAccountLog) throws Exception {
        boolean flag = sysAccountLogService.save(sysAccountLog);
        return ApiResult.result(flag);
    }

    /**
     * 修改账户登录日志
     */
    @PostMapping("/update")
    @ApiOperation(value = "修改SysAccountLog对象", notes = "修改账户登录日志", response = ApiResult.class)
    public ApiResult<Boolean> updateSysAccountLog(@Valid @RequestBody SysAccountLog sysAccountLog) throws Exception {
        boolean flag = sysAccountLogService.updateById(sysAccountLog);
        return ApiResult.result(flag);
    }



    /**
     * 获取账户登录日志
     */
    @PostMapping("/info")
    @ApiOperation(value = "获取SysAccountLog对象详情", notes = "查看账户登录日志", response = SysAccountLogQueryVo.class)
    public ApiResult<SysAccountLogQueryVo> getSysAccountLog(@Valid @RequestBody IdParam idParam) throws Exception {
        SysAccountLogQueryVo sysAccountLogQueryVo = sysAccountLogService.getSysAccountLogById(idParam.getId());
        return ApiResult.ok(sysAccountLogQueryVo);
    }



}

