package com.xdf.creative.module.controller;

import com.xdf.creative.base.controller.BaseController;
import com.xdf.creative.base.params.IdParam;
import com.xdf.creative.base.params.creative.SysOperateLogQueryParam;
import com.xdf.creative.base.vo.creative.SysOperateLogQueryVo;
import com.xdf.creative.module.entity.SysOperateLog;
import com.xdf.creative.module.service.SysOperateLogService;
import com.xdf.creative.util.page.ApiResult;
import com.xdf.creative.util.page.PageTool;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.Valid;

/**
 * <p>
 * 账户操作日志 前端控制器
 * </p>
 *
 * @author lgw
 * @since 2020-03-06
 */
@Slf4j
@RestController
@RequestMapping("/sysOperateLog")
@Api("账户操作日志 API")
public class SysOperateLogController extends BaseController {

    @Autowired
    private SysOperateLogService sysOperateLogService;


    /**
     * 账户操作日志分页列表
     */
    @PostMapping("/getPageList")
    @ApiOperation(value = "获取SysOperateLog分页列表", notes = "账户操作日志分页列表", response = SysOperateLogQueryVo.class)
    public ApiResult<PageTool<SysOperateLogQueryVo>> getSysOperateLogPageList(@Valid @RequestBody SysOperateLogQueryParam sysOperateLogQueryParam) throws Exception {
        PageTool<SysOperateLogQueryVo> pageList = sysOperateLogService.getSysOperateLogPageList(sysOperateLogQueryParam);
        return ApiResult.ok(pageList);
    }

    /**
     * 删除账户操作日志
     */
    @PostMapping("/deleteSysOperateLog")
    @ApiOperation(value = "删除SysOperateLog对象", notes = "删除账户操作日志", response = ApiResult.class)
    public ApiResult<Boolean> deleteSysOperateLog(@Valid @RequestBody IdParam idParam) throws Exception {
        boolean flag = sysOperateLogService.removeById(idParam.getId());
        return ApiResult.result(flag);
    }




    /**
     * 获取账户操作日志
     */
    @PostMapping("/info")
    @ApiOperation(value = "获取SysOperateLog对象详情", notes = "查看账户操作日志", response = SysOperateLogQueryVo.class)
    public ApiResult<SysOperateLogQueryVo> getSysOperateLog(@Valid @RequestBody IdParam idParam) throws Exception {
        SysOperateLogQueryVo sysOperateLogQueryVo = sysOperateLogService.getSysOperateLogById(idParam.getId());
        return ApiResult.ok(sysOperateLogQueryVo);
    }



}

