package com.xdf.creative.module.controller;

import com.xdf.creative.base.controller.BaseController;
import com.xdf.creative.base.params.IdParam;
import com.xdf.creative.base.params.creative.SysOperationLogQueryParam;
import com.xdf.creative.base.vo.creative.SysOperationLogQueryVo;
import com.xdf.creative.module.entity.SysOperationLog;
import com.xdf.creative.module.service.SysOperationLogService;
import com.xdf.creative.util.page.ApiResult;
import com.xdf.creative.util.page.PageTool;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.Valid;

/**
 * <p>
 * 操作日志 前端控制器
 * </p>
 *
 * @author lgw
 * @since 2020-03-02
 */
@Slf4j
@RestController
@RequestMapping("/sysOperationLog")
@Api("操作日志 API")
public class SysOperationLogController extends BaseController {

    @Autowired
    private SysOperationLogService sysOperationLogService;

    /**
     * 添加操作日志
     */
    @PostMapping("/add")
    @ApiOperation(value = "添加SysOperationLog对象", notes = "添加操作日志", response = ApiResult.class)
    public ApiResult<Boolean> addSysOperationLog(@Valid @RequestBody SysOperationLog sysOperationLog) throws Exception {
        boolean flag = sysOperationLogService.save(sysOperationLog);
        return ApiResult.result(flag);
    }

    /**
     * 修改操作日志
     */
    @PostMapping("/update")
    @ApiOperation(value = "修改SysOperationLog对象", notes = "修改操作日志", response = ApiResult.class)
    public ApiResult<Boolean> updateSysOperationLog(@Valid @RequestBody SysOperationLog sysOperationLog) throws Exception {
        boolean flag = sysOperationLogService.updateById(sysOperationLog);
        return ApiResult.result(flag);
    }

    /**
     * 删除操作日志
     */
    @PostMapping("/delete")
    @ApiOperation(value = "删除SysOperationLog对象", notes = "删除操作日志", response = ApiResult.class)
    public ApiResult<Boolean> deleteSysOperationLog(@Valid @RequestBody IdParam idParam) throws Exception {
        boolean flag = sysOperationLogService.removeById(idParam.getId());
        return ApiResult.result(flag);
    }

    /**
     * 获取操作日志
     */
    @PostMapping("/info")
    @ApiOperation(value = "获取SysOperationLog对象详情", notes = "查看操作日志", response = SysOperationLogQueryVo.class)
    public ApiResult<SysOperationLogQueryVo> getSysOperationLog(@Valid @RequestBody IdParam idParam) throws Exception {
        SysOperationLogQueryVo sysOperationLogQueryVo = sysOperationLogService.getSysOperationLogById(idParam.getId());
        return ApiResult.ok(sysOperationLogQueryVo);
    }

    /**
     * 操作日志分页列表
     */
    @PostMapping("/getPageList")
    @ApiOperation(value = "获取SysOperationLog分页列表", notes = "操作日志分页列表", response = SysOperationLogQueryVo.class)
    public ApiResult<PageTool<SysOperationLogQueryVo>> getSysOperationLogPageList(@Valid @RequestBody SysOperationLogQueryParam sysOperationLogQueryParam) throws Exception {
        PageTool<SysOperationLogQueryVo> pageList = sysOperationLogService.getSysOperationLogPageList(sysOperationLogQueryParam);
        return ApiResult.ok(pageList);
    }

}

