
package com.xdf.creative.module.controller;

import com.xdf.creative.base.controller.BaseController;
import com.xdf.creative.base.params.IdParam;
import com.xdf.creative.base.params.creative.SysPermissionCurrentUserParam;
import com.xdf.creative.base.params.creative.SysPermissionQueryParam;
import com.xdf.creative.base.params.creative.SysRoleImpowerPermissionQueryParam;
import com.xdf.creative.base.vo.creative.SysPermissionQueryVo;
import com.xdf.creative.module.entity.InfoType;
import com.xdf.creative.module.entity.SysPermission;
import com.xdf.creative.module.service.SysPermissionService;
import com.xdf.creative.util.page.ApiResult;
import com.xdf.creative.util.page.PageTool;
import com.xdf.creative.util.tree.TreeConfig;
import com.xdf.creative.util.tree.Utils;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import java.util.List;
import java.util.Set;

/**
 * <pre>
 * 系统权限 前端控制器
 * </pre>
 *
 * @author DeanYe
 * @since 2019-10-24
 */
@Slf4j
@RestController
@RequestMapping("/sysPermission")
@Api("系统权限 API")
public class SysPermissionController extends BaseController {

    @Autowired
    private SysPermissionService sysPermissionService;
    /**
     * 获取所有菜单列表
     */
    @PostMapping("/getAllMenuList")
    @ApiOperation(value = "获取所有菜单列表", notes = "获取所有菜单列表", response = SysPermission.class)
    public ApiResult<SysPermission> getAllMenuList() throws Exception {
        List<SysPermission> list = sysPermissionService.getAllMenuList();
        return ApiResult.ok(list);
    }
    /**
     * 角色授权资源树
     */
    @PostMapping("/impowerResourceTreeList")
    @ApiOperation(value = "获取所有菜单列表", notes = "获取所有菜单列表", response = SysPermission.class)
    public ApiResult impowerResourceTreeList(@Valid @RequestBody IdParam idParam) throws Exception {
        List<Object> list = sysPermissionService.impowerResourceTreeList(idParam.getId());
        TreeConfig config = new TreeConfig("resourceId", "parentResourceId", "parentResourceId", "1", "");
        return ApiResult.ok(Utils.tree(list, config));
    }
    /**
     * 角色授权资源
     *
     * @param sysRoleImpowerPermissionQueryParam
     * @return
     * @throws Exception
     */
    @RequestMapping("/setPermissionToRoleByUserId")
    @ApiOperation(value = "给用户角色授权", notes = "给用户角色授权", response = SysPermission.class)
    public ApiResult<Boolean> setPermissionToRoleByUserId(@Valid @RequestBody SysRoleImpowerPermissionQueryParam sysRoleImpowerPermissionQueryParam) throws Exception {
        return sysPermissionService.setPermissionToRoleByUserId(sysRoleImpowerPermissionQueryParam);
    }


    /**
     * 根据用户id获取菜单列表(包含菜单和按钮)
     */
    @GetMapping("/currentUserResource")
    @ApiOperation(value = "根据用户id获取菜单列表", notes = "根据用户id获取菜单列表", response = SysPermission.class)
    public ApiResult currentUserResource(@Valid @RequestBody SysPermissionCurrentUserParam sysPermissionCurrentUserParam) throws Exception {
        List<SysPermission> list = sysPermissionService.currentUserResourceTreeList(sysPermissionCurrentUserParam);
        return ApiResult.ok(list);
    }








    /**
     * 添加系统权限
     */
    @PostMapping("/add")
    @ApiOperation(value = "添加SysPermission对象", notes = "添加系统权限", response = ApiResult.class)
    public ApiResult<Boolean> addSysPermission(@Valid @RequestBody SysPermission sysPermission) throws Exception {
        boolean flag = sysPermissionService.saveSysPermission(sysPermission);
        return ApiResult.result(flag);
    }

    /**
     * 修改系统权限
     */
    @PostMapping("/update")
    @ApiOperation(value = "修改SysPermission对象", notes = "修改系统权限", response = ApiResult.class)
    public ApiResult<Boolean> updateSysPermission(@Valid @RequestBody SysPermission sysPermission) throws Exception {
        boolean flag = sysPermissionService.updateSysPermission(sysPermission);
        return ApiResult.result(flag);
    }

    /**
     * 删除系统权限
     */
    @PostMapping("/deleteSysPermissionById")
    @ApiOperation(value = "删除SysPermission对象", notes = "删除系统权限", response = ApiResult.class)
    public ApiResult<Boolean> deleteSysPermission(String resourceId) throws Exception {
        boolean flag = sysPermissionService.deleteSysPermission(resourceId);
        return ApiResult.result(flag);
    }

    /**
     * 获取系统权限
     */
    @GetMapping("/getSysPermissionById")
    @ApiOperation(value = "获取SysPermission对象详情", notes = "查看系统权限", response = SysPermissionQueryVo.class)
    public ApiResult<SysPermissionQueryVo> getSysPermission(Long id) throws Exception {
        SysPermissionQueryVo sysPermissionQueryVo = sysPermissionService.getSysPermissionById(id);
        return ApiResult.ok(sysPermissionQueryVo);
    }

    /**
     * 系统权限分页列表
     */
    @PostMapping("/getPageList")
    @ApiOperation(value = "获取SysPermission分页列表", notes = "系统权限分页列表", response = SysPermissionQueryVo.class)
    public ApiResult<PageTool<SysPermissionQueryVo>> getSysPermissionPageList(@Valid @RequestBody SysPermissionQueryParam sysPermissionQueryParam) throws Exception {
        PageTool<SysPermissionQueryVo> paging = sysPermissionService.getSysPermissionPageList(sysPermissionQueryParam);
        return ApiResult.ok(paging);
    }


    /**
     * 根据用户id获取菜单列表(不包含按钮)
     */
    @GetMapping("/getMenuListByUserId")
    @ApiOperation(value = "根据用户id获取菜单列表", notes = "根据用户id获取菜单列表", response = SysPermission.class)
    public ApiResult<SysPermission> getMenuListByUserId(Long userId) throws Exception {
        List<SysPermission> list = sysPermissionService.getMenuListByUserId(userId);
        return ApiResult.ok(list);
    }


    /**
     * 根据请userId获取该用户权限路径集合
     */
    @RequestMapping(value = "/getPermissionUrlByUserId", method = {RequestMethod.POST, RequestMethod.GET})
    @ApiOperation(value = "根据请求路径获取该用户权限编码", notes = "根据请求路径获取该用户权限编码", response = ApiResult.class)
    public ApiResult<Set<String>> getPermissionUrlByUserId(Long userId) throws Exception {
        Set<String> permissionUrls = sysPermissionService.getPermissionUrlByUserId(userId);
        return ApiResult.ok(permissionUrls);
    }


    /**
     * 角色授权资源树
     */
/*    @PostMapping("/impowerResourceTreeList")
    @ApiOperation(value = "获取所有菜单列表", notes = "获取所有菜单列表", response = SysPermission.class)
    public ApiResult<SysPermission> impowerResourceTreeList(Long userId) throws Exception {
        List<Object> list = sysPermissionService.impowerResourceTreeList(userId);
        TreeConfig config = new TreeConfig("resourceId", "parentResourceId", "parentResourceId", "1", "");
        return ApiResult.ok(Utils.tree(list, config));
    }*/
    @RequestMapping(value = "/getTreeMenusByUserId", method = {RequestMethod.GET})
    @ApiOperation(value = "根据用户ID获取树形菜单", notes = "根据用户ID获取树形菜单", response = SysPermission.class)
    public ApiResult<List<Object>> getTreeMenusByUserId(Long userId) throws Exception {
        List<Object> treeMenusByUserId = sysPermissionService.getTreeMenusByUserId(userId);
        return ApiResult.ok(treeMenusByUserId);
    }


    @RequestMapping(value = "/getSkipAuthUrls", method = {RequestMethod.GET})
    @ApiOperation(value = "获取无需鉴权URL", notes = "获取无需鉴权URL", response = SysPermission.class)
    public ApiResult<List<String>> getSkipAuthUrls() throws Exception {
        List<String> skipAuthUrls = sysPermissionService.getSkipAuthUrls();
        return ApiResult.ok(skipAuthUrls);
    }


    @RequestMapping(value = "/refreshSkipAuthUrls", method = {RequestMethod.POST})
    @ApiOperation(value = "刷新SkipAuthUrls", notes = "刷新SkipAuthUrls", response = SysPermission.class)
    public ApiResult refreshSkipAuthUrls() throws Exception {
        List<String> skipAuthUrls = sysPermissionService.getSkipAuthUrls();
        //    redisTemplate.convertAndSend("skipAuthUrls", skipAuthUrls);//发送对列消息
        return ApiResult.ok();
    }


}

