
package com.xdf.creative.module.controller;

import com.xdf.creative.base.controller.BaseController;
import com.xdf.creative.base.params.IdParam;
import com.xdf.creative.base.params.creative.AddSysRoleParam;
import com.xdf.creative.base.params.creative.SysRoleQueryParam;
import com.xdf.creative.base.params.creative.UpdateSysRoleParam;
import com.xdf.creative.base.vo.creative.SysRoleQueryVo;
import com.xdf.creative.enums.StatusCode;
import com.xdf.creative.module.service.SysRoleService;
import com.xdf.creative.support.aop.OperateLogger;
import com.xdf.creative.util.StringUtil;
import com.xdf.creative.util.page.ApiResult;
import com.xdf.creative.util.page.PageTool;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import java.util.List;

/**
 * <pre>
 * 系统角色 前端控制器
 * </pre>
 *
 * @author DeanYe
 * @since 2019-10-24
 */
@Slf4j
@RestController
@RequestMapping("/sysRole")
@Api("系统角色 API")
public class SysRoleController extends BaseController {

    @Autowired
    private SysRoleService sysRoleService;

    /**
     * 添加系统角色
     */
    @PostMapping("/addSysRole")
    @ApiOperation(value = "添加SysRole对象", notes = "添加系统角色", response = ApiResult.class)
    @OperateLogger(name = "添加角色",attributeId="id",attributeName="name")
    public ApiResult addSysRole(@Valid @RequestBody SysRoleQueryParam sysRoleQueryParam) throws Exception {
        return sysRoleService.addSysRole(sysRoleQueryParam);
    }
    /**
     * 修改系统角色
     */
    @PostMapping("/updateSysRole")
    @ApiOperation(value = "添加SysRole对象", notes = "添加系统角色", response = ApiResult.class)
    @OperateLogger(name = "修改角色",attributeId="id",attributeName="name")
    public ApiResult updateSysRole(@Valid @RequestBody SysRoleQueryParam sysRoleQueryParam) throws Exception {
        return sysRoleService.updateSysRole(sysRoleQueryParam);
    }
    /**
     * 删除系统角色
     */
    @PostMapping("/deleteSysRole")
    @ApiOperation(value = "删除SysRole对象", notes = "删除系统角色", response = ApiResult.class)
    @OperateLogger(name = "删除角色",attributeId="id",attributeName="value")
    public ApiResult<Boolean> deleteSysRole(@Valid @RequestBody IdParam idParam) throws Exception {
        return sysRoleService.deleteSysRole(idParam.getId());
    }

    /**
     * 根据UserId系统角色列表
     */
    @PostMapping(value = "/getRoleList")
    @ApiOperation(value = "获取SysRole列表", notes = "系统角色列表", response = SysRoleQueryVo.class)
    public ApiResult  getRoleList() {
        return sysRoleService.getRoleList();
    }




    /**
     *验证系统角色是否存在
     */
    @PostMapping("/verifySysRole")
    @ApiOperation(value = "验证系统角色是否存在", notes = "验证系统角色是否存在", response = ApiResult.class)

    public ApiResult verifySysRole(@RequestBody SysRoleQueryParam sysRoleQueryParam) throws Exception {
        if(StringUtil.isEmpty(sysRoleQueryParam.getName())){
            return ApiResult.fail("请输入角色名！");
        }
        boolean isExists = sysRoleService.isExistsByRoleName(sysRoleQueryParam.getName());
        if (isExists) {
            return ApiResult.error(StatusCode.SYS_ROLE_EXIST);
        }else{
            return ApiResult.ok();
        }


    }








    /**
     * 获取系统角色
     */
    @GetMapping("/getSysRoleInfo")
    @ApiOperation(value = "获取SysRole对象详情", notes = "查看系统角色", response = SysRoleQueryVo.class)
    public ApiResult<SysRoleQueryVo> getSysRole(Long id) throws Exception {
        SysRoleQueryVo sysRoleQueryVo = sysRoleService.getSysRoleById(id);
        return ApiResult.ok(sysRoleQueryVo);
    }

    /**
     * 系统角色分页列表
     */
    @PostMapping("/getPageList")
    @ApiOperation(value = "获取SysRole分页列表", notes = "系统角色分页列表", response = SysRoleQueryVo.class)
    public ApiResult<PageTool<SysRoleQueryVo>> getSysRolePageList(@Valid @RequestBody SysRoleQueryParam sysRoleQueryParam) throws Exception {
        PageTool<SysRoleQueryVo> pageList = sysRoleService.getSysRolePageList(sysRoleQueryParam);
        return ApiResult.ok(pageList);
    }

    /**
     * 根据UserId系统角色列表
     */
    @RequestMapping(value = "/getUserRoleByUserId", method = {RequestMethod.GET, RequestMethod.POST})
    @ApiOperation(value = "获取SysRole列表", notes = "系统角色列表", response = SysRoleQueryVo.class)
    public ApiResult<List<SysRoleQueryVo>> getUserRoleByUserId(@RequestParam Long userId) {
        List<SysRoleQueryVo> vos = sysRoleService.getUserRoleByUserId(userId);
        return ApiResult.ok(vos);
    }

}

