package com.xdf.creative.module.controller;

import com.xdf.creative.base.controller.BaseController;
import com.xdf.creative.base.params.IdParam;
import com.xdf.creative.base.params.creative.WebInitiationApplyQueryParam;
import com.xdf.creative.base.vo.creative.WebInitiationApplyQueryVo;
import com.xdf.creative.enums.InitiationApplryAduitStateEnum;
import com.xdf.creative.enums.StatusCode;
import com.xdf.creative.module.entity.WebInitiationApply;
import com.xdf.creative.module.service.WebInitiationApplyService;
import com.xdf.creative.shiro.jwt.JwtUtil;
import com.xdf.creative.util.page.ApiResult;
import com.xdf.creative.util.page.PageTool;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.Valid;
import java.util.Date;

/**
 * <p>
 * 文促会入会申请表 前端控制器
 * </p>
 *
 * @author DeanYe
 * @since 2019-10-30
 */
@Slf4j
@RestController
@RequestMapping("/webInitiationApply")
@Api("文促会入会申请表 API")
public class WebInitiationApplyController extends BaseController {

    @Autowired
    private WebInitiationApplyService webInitiationApplyService;

    /**
     * 添加文促会入会申请表
     */
    @PostMapping("/add")
    @ApiOperation(value = "添加WebInitiationApply对象", notes = "添加文促会入会申请表", response = ApiResult.class)
    public ApiResult<Boolean> addWebInitiationApply(@Valid @RequestBody WebInitiationApply webInitiationApply) throws Exception {
        webInitiationApply.setFirstAudit(InitiationApplryAduitStateEnum.INITIATION_APPLRY_ADUIT_STATE_WAIT.getCode());
        boolean flag = webInitiationApplyService.save(webInitiationApply);
        return ApiResult.result(flag);
    }

    /**
     * 修改文促会入会申请表
     */
    @PostMapping("/update")
    @ApiOperation(value = "修改WebInitiationApply对象", notes = "修改文促会入会申请表", response = ApiResult.class)
    public ApiResult<Boolean> updateWebInitiationApply(@RequestBody WebInitiationApply webInitiationApply) throws Exception {
        if (0 == webInitiationApply.getId()) {
            return ApiResult.error(StatusCode.FORM_SUBMIT_ID_VERIFY);
        }
        webInitiationApply.setUpdateTime(new Date());
        boolean flag = webInitiationApplyService.updateById(webInitiationApply);
        return ApiResult.result(flag);
    }


    /**
     * 文促会入会申请初审
     */
    @PostMapping("/firstAudit")
    @ApiOperation(value = "修改WebInitiationApply对象", notes = "文促会入会申请初审", response = ApiResult.class)
    public ApiResult<Boolean> firstAudit(@RequestBody WebInitiationApply webInitiationApply) throws Exception {
        if (null == webInitiationApply.getId()) {
            return ApiResult.error(StatusCode.FORM_SUBMIT_ID_VERIFY);
        }
        if (null == webInitiationApply.getFirstAudit()) {
            return ApiResult.error(StatusCode.WEB_INITIATION_APPLY_FIRST_AUDIT);
        }
        WebInitiationApply webInitiationApplyNew = webInitiationApplyService.getById(webInitiationApply.getId());
        if (null == webInitiationApplyNew) {
            return ApiResult.error(StatusCode.FORM_SUBMIT_UPDATE_VERIFY);
        }

        if (InitiationApplryAduitStateEnum.INITIATION_APPLRY_ADUIT_STATE_PASS.getCode().equals(webInitiationApply.getFirstAudit())) {
            webInitiationApplyNew.setCreditAudit(InitiationApplryAduitStateEnum.INITIATION_APPLRY_ADUIT_STATE_WAIT.getCode());
        }
        webInitiationApplyNew.setFirstAudit(webInitiationApply.getFirstAudit());
        webInitiationApplyNew.setFirstAuditCause(webInitiationApply.getFirstAuditCause());
        webInitiationApplyNew.setFirstAuditTime(new Date());
        webInitiationApplyNew.setFirstAuditUserId(JwtUtil.getUserId(getRequest().getHeader("token")));
        webInitiationApplyNew.setUpdateTime(new Date());
        boolean flag = webInitiationApplyService.updateById(webInitiationApplyNew);
        return ApiResult.result(flag);
    }

    /**
     * 文促会入会审核报送
     */
    @PostMapping("/sendAudit")
    @ApiOperation(value = "修改WebInitiationApply对象", notes = "文促会入会审核报送", response = ApiResult.class)
    public ApiResult<Boolean> sendAudit(@RequestBody WebInitiationApply webInitiationApply) throws Exception {
        return webInitiationApplyService.sendAudit(webInitiationApply);
    }


    /**
     * 文促会入会信用审核
     */
    @PostMapping("/creditAudit")
    @ApiOperation(value = "修改WebInitiationApply对象", notes = "文促会入会信用审核", response = ApiResult.class)
    public ApiResult<Boolean> creditAudit(@RequestBody WebInitiationApply webInitiationApply) throws Exception {
        if (0 == webInitiationApply.getId()) {
            return ApiResult.error(StatusCode.FORM_SUBMIT_ID_VERIFY);
        }
        if (null == webInitiationApply.getCreditAudit()) {
            return ApiResult.error(StatusCode.WEB_INITIATION_APPLY_FIRST_AUDIT);
        }
        WebInitiationApply webInitiationApplyNew = webInitiationApplyService.getById(webInitiationApply.getId());
        if (null == webInitiationApplyNew) {
            return ApiResult.error(StatusCode.FORM_SUBMIT_UPDATE_VERIFY);
        }
        if (InitiationApplryAduitStateEnum.INITIATION_APPLRY_ADUIT_STATE_PASS.getCode().equals(webInitiationApply.getCreditAudit())) {
            webInitiationApplyNew.setFinalAudit(InitiationApplryAduitStateEnum.INITIATION_APPLRY_ADUIT_STATE_WAIT.getCode());
        }
        webInitiationApplyNew.setCreditAudit(webInitiationApply.getCreditAudit());
        webInitiationApplyNew.setCreditAuditCause(webInitiationApply.getCreditAuditCause());
        webInitiationApplyNew.setCreditAuditTime(new Date());
        webInitiationApplyNew.setCreditAuditUserId(JwtUtil.getUserId(getRequest().getHeader("token")));
        webInitiationApplyNew.setUpdateTime(new Date());
        boolean flag = webInitiationApplyService.updateById(webInitiationApplyNew);
        return ApiResult.result(flag);
    }

    /**
     * 文促会入会最终审核
     */
    @PostMapping("/finnalAudit")
    @ApiOperation(value = "修改WebInitiationApply对象", notes = "文促会入会最终审核", response = ApiResult.class)
    public ApiResult<Boolean> finnalAudit(@RequestBody WebInitiationApply webInitiationApply) throws Exception {
        if (0 == webInitiationApply.getId()) {
            return ApiResult.error(StatusCode.FORM_SUBMIT_ID_VERIFY);
        }
        if (null == webInitiationApply.getFinalAudit()) {
            return ApiResult.error(StatusCode.WEB_INITIATION_APPLY_FIRST_AUDIT);
        }
        WebInitiationApply webInitiationApplyNew = webInitiationApplyService.getById(webInitiationApply.getId());
        if (null == webInitiationApplyNew) {
            return ApiResult.error(StatusCode.FORM_SUBMIT_UPDATE_VERIFY);
        }
        webInitiationApplyNew.setFinalAudit(webInitiationApply.getFinalAudit());
        webInitiationApplyNew.setFinalAuditCause(webInitiationApply.getFinalAuditCause());
        webInitiationApplyNew.setFinalAuditTime(new Date());
        webInitiationApplyNew.setFinalAuditUserId(JwtUtil.getUserId(getRequest().getHeader("token")));
        webInitiationApplyNew.setUpdateTime(new Date());
        boolean flag = webInitiationApplyService.updateById(webInitiationApplyNew);
        return ApiResult.result(flag);
    }


    /**
     * 删除文促会入会申请表
     */
    @PostMapping("/delete")
    @ApiOperation(value = "删除WebInitiationApply对象", notes = "删除文促会入会申请表", response = ApiResult.class)
    public ApiResult<Boolean> deleteWebInitiationApply(@Valid @RequestBody IdParam idParam) throws Exception {
        boolean flag = webInitiationApplyService.removeById(idParam.getId());
        return ApiResult.result(flag);
    }


    /**
     * 获取文促会入会申请表
     */
    @PostMapping("/info")
    @ApiOperation(value = "获取WebInitiationApply对象详情", notes = "查看文促会入会申请表", response = WebInitiationApplyQueryVo.class)
    public ApiResult<WebInitiationApplyQueryVo> getWebInitiationApply(@Valid @RequestBody IdParam idParam) throws Exception {
        WebInitiationApplyQueryVo webInitiationApplyQueryVo = webInitiationApplyService.getWebInitiationApplyById(idParam.getId());
        return ApiResult.ok(webInitiationApplyQueryVo);
    }


    /**
     * 文促会入会申请管理员查询所有
     */
    @PostMapping("/getPageListBack")
    @ApiOperation(value = "获取WebInitiationApply分页列表", notes = "文促会入会申请管理员查询所有", response = WebInitiationApplyQueryVo.class)
    public ApiResult<PageTool<WebInitiationApplyQueryVo>> getWebInitiationApplyPageListBack(@RequestBody WebInitiationApplyQueryParam webInitiationApplyQueryParam) throws Exception {
        PageTool<WebInitiationApplyQueryVo> pageList = webInitiationApplyService.getWebInitiationApplyPageListBack(webInitiationApplyQueryParam);
        return ApiResult.ok(pageList);
    }


    /**
     * 文促会成员web首页查询查询所有
     */
    @PostMapping("/getPageListHome")
    @ApiOperation(value = "获取WebInitiationApply分页列表", notes = "文促会入会申请管理员查询所有", response = WebInitiationApplyQueryVo.class)
    public ApiResult<PageTool<WebInitiationApplyQueryVo>> getWebInitiationApplyPageListHome(@RequestBody WebInitiationApplyQueryParam webInitiationApplyQueryParam) throws Exception {
        PageTool<WebInitiationApplyQueryVo> pageList = webInitiationApplyService.getWebInitiationApplyPageListHome(webInitiationApplyQueryParam);
        return ApiResult.ok(pageList);
    }

    /**
     * 文促会入会申请初审人员查询
     */
    @PostMapping("/getPageListByFirstAudit")
    @ApiOperation(value = "获取WebInitiationApply分页列表", notes = "文促会入会申请初审人员查询", response = WebInitiationApplyQueryVo.class)
    public ApiResult<PageTool<WebInitiationApplyQueryVo>> getPageListByFirstAudit(@RequestBody WebInitiationApplyQueryParam webInitiationApplyQueryParam) throws Exception {
        PageTool<WebInitiationApplyQueryVo> pageList = webInitiationApplyService.getPageListByFirstAudit(webInitiationApplyQueryParam);
        return ApiResult.ok(pageList);
    }

    /**
     * 文促会入会申请信用审核人员查询
     */
    @PostMapping("/getPageListByCreditAudit")
    @ApiOperation(value = "获取WebInitiationApply分页列表", notes = "文促会入会申请信用审核人员查询", response = WebInitiationApplyQueryVo.class)
    public ApiResult<PageTool<WebInitiationApplyQueryVo>> getPageListByCreditAudit(@RequestBody WebInitiationApplyQueryParam webInitiationApplyQueryParam) throws Exception {

        PageTool<WebInitiationApplyQueryVo> pageList = webInitiationApplyService.getPageListByCreditAudit(webInitiationApplyQueryParam);
        return ApiResult.ok(pageList);
    }


    /**
     * 文促会入会申请终审人员查询
     */
    @PostMapping("/getPageListByFinalAudit")
    @ApiOperation(value = "获取WebInitiationApply分页列表", notes = "文促会入会申请终审人员查询", response = WebInitiationApplyQueryVo.class)
    public ApiResult<PageTool<WebInitiationApplyQueryVo>> getPageListByFinalAudit(@RequestBody WebInitiationApplyQueryParam webInitiationApplyQueryParam) throws Exception {

        PageTool<WebInitiationApplyQueryVo> pageList = webInitiationApplyService.getPageListByFinalAudit(webInitiationApplyQueryParam);
        return ApiResult.ok(pageList);
    }


    @PostMapping("/getExportPageList")
    @ApiOperation(value = "获取WebInitiationApply分页列表", notes = "文促会入会申请终审人员查询", response = WebInitiationApplyQueryVo.class)
    public ApiResult getExportPageList(@RequestBody WebInitiationApplyQueryParam webInitiationApplyQueryParam) throws Exception {
        return  webInitiationApplyService.getExportPageList(webInitiationApplyQueryParam,getRequest());
    }

}

