package com.xdf.creative.module.controller;

import com.xdf.creative.base.controller.BaseController;
import com.xdf.creative.base.params.IdParam;
import com.xdf.creative.base.params.creative.WxGroupQueryParam;
import com.xdf.creative.base.vo.creative.WxGroupQueryVo;
import com.xdf.creative.enums.StateEnum;
import com.xdf.creative.module.entity.WxGroup;
import com.xdf.creative.module.service.WxGroupService;
import com.xdf.creative.util.page.ApiResult;
import com.xdf.creative.util.page.PageTool;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.Valid;
import java.util.Date;

/**
 * <p>
 * 微信群二维码 前端控制器
 * </p>
 *
 * @author lgw
 * @since 2021-01-28
 */
@Slf4j
@RestController
@RequestMapping("/wxGroup")
@Api("微信群二维码 API")
public class WxGroupController extends BaseController {

    @Autowired
    private WxGroupService wxGroupService;

    /**
     * 添加微信群二维码
     */
    @PostMapping("/add")
    @ApiOperation(value = "添加WxGroup对象", notes = "添加微信群二维码", response = ApiResult.class)
    public ApiResult<Boolean> addWxGroup(@Valid @RequestBody WxGroup wxGroup) throws Exception {
        boolean flag = wxGroupService.save(wxGroup);
        return ApiResult.result(flag);
    }

    /**
     * 修改微信群二维码
     */
    @PostMapping("/update")
    @ApiOperation(value = "修改WxGroup对象", notes = "修改微信群二维码", response = ApiResult.class)
    public ApiResult<Boolean> updateWxGroup(@Valid @RequestBody WxGroup wxGroup) throws Exception {
        wxGroup.setUpdateTime(new Date());
        boolean flag = wxGroupService.updateById(wxGroup);
        return ApiResult.result(flag);
    }

    /**
     * 删除微信群二维码
     */
    @PostMapping("/delete")
    @ApiOperation(value = "删除WxGroup对象", notes = "删除微信群二维码", response = ApiResult.class)
    public ApiResult<Boolean> deleteWxGroup(@Valid @RequestBody IdParam idParam) throws Exception {
        boolean flag = wxGroupService.removeById(idParam.getId());
        return ApiResult.result(flag);
    }

    /**
     * 获取微信群二维码
     */
    @PostMapping("/info")
    @ApiOperation(value = "获取WxGroup对象详情", notes = "查看微信群二维码", response = WxGroupQueryVo.class)
    public ApiResult<WxGroupQueryVo> getWxGroup(@Valid @RequestBody IdParam idParam) throws Exception {
        WxGroupQueryVo wxGroupQueryVo = wxGroupService.getWxGroupById(idParam.getId());
        return ApiResult.ok(wxGroupQueryVo);
    }

    /**
     * 微信群二维码分页列表
     */
    @PostMapping("/getPageList")
    @ApiOperation(value = "获取WxGroup分页列表", notes = "微信群二维码分页列表", response = WxGroupQueryVo.class)
    public ApiResult<PageTool<WxGroupQueryVo>> getWxGroupPageList(@RequestBody WxGroupQueryParam wxGroupQueryParam) throws Exception {
        PageTool<WxGroupQueryVo> pageList = wxGroupService.getWxGroupPageList(wxGroupQueryParam);
        return ApiResult.ok(pageList);
    }

    @PostMapping("/getWebList")
    @ApiOperation(value = "获取WxGroup分页列表", notes = "微信群二维码分页列表", response = WxGroupQueryVo.class)
    public ApiResult<PageTool<WxGroupQueryVo>> getWebList() throws Exception {
        WxGroupQueryParam wxGroupQueryParam =new WxGroupQueryParam();
        wxGroupQueryParam.setState(StateEnum.ENABLE.getKey());
        wxGroupQueryParam.setPageNum(1);
        wxGroupQueryParam.setPageSize(30);
        PageTool<WxGroupQueryVo> pageList = wxGroupService.getWxGroupPageList(wxGroupQueryParam);
        return ApiResult.ok(pageList);
    }


    /**
     * 启用停用关键字
     * @param idParam
     * @return
     * @throws Exception
     */
    @PostMapping("/enable")
    @ApiOperation(value = "启用停用", notes = "删除信息关键字", response = ApiResult.class)
    public ApiResult enable(@Valid @RequestBody IdParam idParam) throws Exception {
        return wxGroupService.enable(idParam.getId());
    }

}

