
package com.xdf.creative.module.service;


import com.xdf.creative.base.params.creative.SysPermissionCurrentUserParam;
import com.xdf.creative.base.params.creative.SysPermissionQueryParam;
import com.xdf.creative.base.params.creative.SysRoleImpowerPermissionQueryParam;
import com.xdf.creative.base.service.BaseService;
import com.xdf.creative.base.vo.creative.SysPermissionQueryVo;
import com.xdf.creative.base.vo.creative.SysPermissionUserVo;
import com.xdf.creative.module.entity.InfoType;
import com.xdf.creative.module.entity.SysPermission;
import com.xdf.creative.util.page.ApiResult;
import com.xdf.creative.util.page.PageTool;
import org.apache.ibatis.annotations.Param;

import java.io.Serializable;
import java.util.List;
import java.util.Map;
import java.util.Set;

/**
 * <pre>
 * 系统权限 服务类
 * </pre>
 *
 * @author DeanYe
 * @since 2019-10-24
 */
public interface SysPermissionService extends BaseService<SysPermission> {

    /**
     * 给管理角色员赋予所有权限
     * @return
     * @throws Exception
     */
    ApiResult setPermissionToRoleByUserId(SysRoleImpowerPermissionQueryParam sysRoleImpowerPermissionQueryParam) throws Exception;

    /**
     * 保存
     *
     * @param sysPermission
     * @return
     * @throws Exception
     */
    boolean saveSysPermission(SysPermission sysPermission) throws Exception;

    /**
     * 修改
     *
     * @param sysPermission
     * @return
     * @throws Exception
     */
    boolean updateSysPermission(SysPermission sysPermission) throws Exception;

    /**
     * 删除
     *
     * @param resourceId
     * @return
     * @throws Exception
     */
    boolean deleteSysPermission(String resourceId) throws Exception;

    /**
     * 根据ID获取查询对象
     *
     * @param resourceId
     * @return
     * @throws Exception
     */
    SysPermissionQueryVo getSysPermissionById(Serializable resourceId) throws Exception;

    /**
     * 获取分页对象
     *
     * @param sysPermissionQueryParam
     * @return
     * @throws Exception
     */
    PageTool<SysPermissionQueryVo> getSysPermissionPageList(SysPermissionQueryParam sysPermissionQueryParam) throws Exception;

    /**
     * 判断权限id是否存在
     *
     * @param permissionIds
     * @return
     * @throws Exception
     */
    boolean isExistsByPermissionIds(List<String> permissionIds) throws Exception;

    /**
     * 获取所有菜单列表
     *
     * @return
     * @throws Exception
     */
    List<SysPermission> getAllMenuList() throws Exception;

    /**
     * 获取角色授权资源树
     *
     * @return
     * @throws Exception
     */
    List<Object> impowerResourceTreeList(Long userId) throws Exception;


    /**
     * 根据用户id获取菜单列表
     *
     * @param userId
     * @return
     * @throws Exception
     */
    List<SysPermission> getMenuListByUserId(Long userId) throws Exception;


    /**
     * @param userId
     * @return 获取用户已得到得权限 包含菜单
     * @throws Exception
     */
    List<Object> getTreeMenusByUserId(Long userId) throws Exception;


    /**
     * 获取用户已得到得权限 包含菜单和按钮
     * @param sysPermissionCurrentUserParam
     * @return
     * @throws Exception
     */
     List<SysPermission> currentUserResourceTreeList(SysPermissionCurrentUserParam sysPermissionCurrentUserParam) throws Exception;


    /**
     * 根据请用户id取权限路径集合
     *
     * @param userId
     * @return
     */
    Set<String> getPermissionUrlByUserId(Long userId) throws Exception;



    /**
     *
     * 根据用户Id获取权限
     * @param userId
     * @return
     */
    Map<String,Object> getPermissionByUserId(@Param("userId") Long userId);



    /**
     * 获取不需要鉴权url
     *
     * @return
     */
    List<String> getSkipAuthUrls() throws Exception;

}
