package com.xdf.creative.module.service.impl;

import com.xdf.creative.base.params.WebParkEnterApplyEmailParam;
import com.xdf.creative.enums.ApiCode;
import com.xdf.creative.enums.DeviceEnum;
import com.xdf.creative.module.service.EmailService;
import com.xdf.creative.util.page.ApiResult;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.mail.SimpleMailMessage;
import org.springframework.mail.javamail.JavaMailSender;
import org.springframework.stereotype.Service;
import org.springframework.transaction.interceptor.TransactionAspectSupport;

@Slf4j
@Service
public class EmailServiceImpl implements EmailService {


    @Autowired
    private JavaMailSender mailSender;

    @Value("${mail_fromMail_addr}")
    private String from;

    @Value("${mail_toMail_addr}")
    private String to;


    @Override
    public ApiResult sendSimpleMail(String to, String subject, String content) throws Exception {
        // 创建邮件内容
        SimpleMailMessage message = new SimpleMailMessage();
        message.setFrom(from);
        message.setTo(to);
        message.setSubject(subject);
        message.setText(content);
        try {
            mailSender.send(message);
            // 发送成功修改状态
            log.info("简单邮件已经发送。");

        } catch (Exception e) {
            System.err.println("错误信息：" + e.getMessage());
            log.error("发送简单邮件时出现异常。:");

            TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
            return ApiResult.fail("发送邮件失败");
        }
        return ApiResult.ok();
    }


    @Override
    public ApiResult sendParkEnterMail(WebParkEnterApplyEmailParam webParkEnterApplyEmailParam) throws Exception {
        ApiResult result = this.sendSimpleMail(to, "文创办园区入驻", "【文创办】企业：" + webParkEnterApplyEmailParam.getCompanyName() + "通过"+(DeviceEnum.ONE.getKey().equals(webParkEnterApplyEmailParam.getSource())? DeviceEnum.ONE.getValue():DeviceEnum.TWO.getValue())+"向《" + webParkEnterApplyEmailParam.getParkName() + "》提交入驻申请，联系信息如下-》" + "姓名：" + webParkEnterApplyEmailParam.getLinkMan() + ",职务：" + webParkEnterApplyEmailParam.getDuty() + ",联系电话：" + webParkEnterApplyEmailParam.getMobile() + "。请及时关注！");
        if (ApiCode.SUCCESS.getCode() != result.getCode()) {
            return result;
        }
        return ApiResult.ok();
    }


}
