package com.xdf.creative.module.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.xdf.creative.base.params.creative.InfoKeywordAddParam;
import com.xdf.creative.base.params.creative.InfoKeywordQueryParam;
import com.xdf.creative.base.params.creative.InfoKeywordSaveCheckParam;
import com.xdf.creative.base.service.impl.BaseServiceImpl;
import com.xdf.creative.base.vo.creative.InfoKeywordCheckListVo;
import com.xdf.creative.base.vo.creative.InfoKeywordQueryVo;
import com.xdf.creative.constant.CommonConstant;
import com.xdf.creative.enums.StateEnum;
import com.xdf.creative.enums.StatusCode;
import com.xdf.creative.module.entity.InfoContent;
import com.xdf.creative.module.entity.InfoContentKeyword;
import com.xdf.creative.module.entity.InfoKeyword;
import com.xdf.creative.module.mapper.InfoKeywordMapper;
import com.xdf.creative.module.service.InfoContentKeywordService;
import com.xdf.creative.module.service.InfoContentService;
import com.xdf.creative.module.service.InfoKeywordService;
import com.xdf.creative.util.page.ApiResult;
import com.xdf.creative.util.page.PageTool;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;


/**
 * <p>
 * 信息关键字 服务实现类
 * </p>
 *
 * @author lgw
 * @since 2020-11-27
 */
@Slf4j
@Service
@Transactional(rollbackFor = Exception.class)
public class InfoKeywordServiceImpl extends BaseServiceImpl<InfoKeywordMapper, InfoKeyword> implements InfoKeywordService {

    @Autowired
    private InfoKeywordMapper infoKeywordMapper;
    @Autowired
    private InfoContentKeywordService infoContentKeywordService;
    @Autowired
    private InfoContentService infoContentService;


    /**
     * 添加关键词
     * @param infoKeywordAddParam
     * @return
     */
    @Override
    public ApiResult add(InfoKeywordAddParam infoKeywordAddParam) {
        InfoKeyword infoKeyword = new InfoKeyword();
        BeanUtils.copyProperties(infoKeywordAddParam, infoKeyword);
        infoKeyword.setId(null);
        infoKeyword.setCreateUser(getUserId());
        infoKeyword.setState(StateEnum.ENABLE.getKey());
        if (StateEnum.ENABLE.getKey().equals(infoKeyword.getIsUse())) {
            if (this.count(new QueryWrapper<InfoKeyword>().eq("state", StateEnum.ENABLE.getKey()).eq("is_use", StateEnum.ENABLE.getKey())) >= CommonConstant.KEY_WORD_MAX_SIZE) {
                return ApiResult.fail("常用关键字不能操作"+ CommonConstant.KEY_WORD_MAX_SIZE+"个");
            }
        }
        this.saveOrUpdate(infoKeyword);
        return ApiResult.ok();
    }

    /**
     * 编辑关键词
     * @param infoKeywordAddParam
     * @return
     */
    @Override
    public ApiResult edit(InfoKeywordAddParam infoKeywordAddParam) {
        InfoKeyword infoKeyword = this.getById(infoKeywordAddParam.getId());
        if (null == infoKeyword) {
            return ApiResult.error(StatusCode.FORM_SUBMIT_UPDATE_VERIFY);
        }
        if (StateEnum.ENABLE.getKey().equals(infoKeywordAddParam.getIsUse())) {
            if (this.count(new QueryWrapper<InfoKeyword>().eq("state", StateEnum.ENABLE.getKey()).eq("is_use", StateEnum.ENABLE.getKey())) >= CommonConstant.KEY_WORD_MAX_SIZE) {
                return ApiResult.fail("常用关键字不能操作"+ CommonConstant.KEY_WORD_MAX_SIZE+"个");
            }
        }
        BeanUtils.copyProperties(infoKeywordAddParam, infoKeyword);
        this.saveOrUpdate(infoKeyword);
        return ApiResult.ok();
    }

    /**
     * 启用停用关键词
     * @param id
     * @return
     */
    @Override
    public ApiResult enable(Serializable id) {
        InfoKeyword infoKeyword = this.getById(id);
        if (null == infoKeyword) {
            return ApiResult.error(StatusCode.FORM_SUBMIT_UPDATE_VERIFY);
        }
        if (StateEnum.ENABLE.getKey().equals(infoKeyword.getState())) {
            infoKeyword.setState(StateEnum.DISABLE.getKey());
        } else {
            infoKeyword.setState(StateEnum.ENABLE.getKey());
        }
        this.saveOrUpdate(infoKeyword);
        return ApiResult.ok();
    }

    /**
     * 删除关键字
     * @param id
     * @return
     */
    @Override
    public ApiResult del(Serializable id) {
        InfoKeyword infoKeyword = this.getById(id);
        if(null==infoKeyword){
            return ApiResult.error(StatusCode.FORM_SUBMIT_UPDATE_VERIFY);
        }
        if(StateEnum.ENABLE.getKey().equals(infoKeyword.getState())){
            return ApiResult.fail("只能删除已停用的关键词！");
        }
        if(infoContentKeywordService.count(new QueryWrapper<InfoContentKeyword>().eq("keyword_id",id))>0){
            return ApiResult.fail("当前关键字已经被绑定，只能停用！");
        }
        this.removeById(infoKeyword);
        return ApiResult.ok();
    }

    /**
     * 获取已选择关键词列表
     * @param contentId
     * @return
     */
    @Override
    public ApiResult getCheckList(Serializable contentId) {
        return ApiResult.ok(baseMapper.getCheckList(contentId));
    }




    /**
     * 给新闻添加关键字
     * @param infoKeywordSaveCheckParam
     * @return
     */
    @Override
    @Transactional
    public ApiResult saveCheckList(InfoKeywordSaveCheckParam infoKeywordSaveCheckParam) {
        List<Long> keyIds =infoKeywordSaveCheckParam.getKeyIds();
        if(null==keyIds||keyIds.size()<=0){
            return ApiResult.fail("请选择关键词！");
        }
        InfoContent infoContent = infoContentService.getById(infoKeywordSaveCheckParam.getContentId());
        if(null == infoContent){
            return ApiResult.error(StatusCode.FORM_SUBMIT_UPDATE_VERIFY);
        }
        List<InfoContentKeyword> infoContentKeywordList = new ArrayList<>();
        if(infoContentKeywordService.remove(new QueryWrapper<InfoContentKeyword>().eq("content_id",infoContent.getId()))){
            for (Long keyId:keyIds
            ) {
                InfoKeyword infoKeyword = this.getById(keyId);
                if(null!=infoKeyword&& StateEnum.ENABLE.getKey().equals(infoKeyword.getState())){
                    InfoContentKeyword infoContentKeyword = new InfoContentKeyword();
                    infoContentKeyword.setContentId(infoContent.getId()).setKeywordId(infoKeyword.getId()).setCreateTime(new Date());
                    infoContentKeywordList.add(infoContentKeyword);
                }
            }
        }
        infoContentKeywordService.saveBatch(infoContentKeywordList);
        return ApiResult.ok();
    }

    @Override
    public List<InfoKeywordCheckListVo> getKeywordListByContentId(Serializable contentId) {
        return baseMapper.getKeywordListByContentId(contentId);
    }

    @Override
    public InfoKeywordQueryVo getInfoKeywordById(Serializable id) throws Exception {
        return infoKeywordMapper.getInfoKeywordById(id);
    }

    @Override
    public PageTool<InfoKeywordQueryVo> getInfoKeywordPageList(InfoKeywordQueryParam infoKeywordQueryParam) throws Exception {
        Page page = setPageParam(infoKeywordQueryParam);
        IPage<InfoKeywordQueryVo> iPage = infoKeywordMapper.getInfoKeywordPageList(page, infoKeywordQueryParam);
        return new PageTool(iPage);
    }

}
