package com.xdf.creative.module.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.xdf.creative.base.params.creative.InfoRoleImpowerTypeQueryParam;
import com.xdf.creative.base.params.creative.InfoRoleTypeQueryParam;
import com.xdf.creative.base.service.impl.BaseServiceImpl;
import com.xdf.creative.base.vo.creative.InfoRoleTypeQueryVo;
import com.xdf.creative.base.vo.creative.SysRoleQueryVo;
import com.xdf.creative.enums.StatusCode;
import com.xdf.creative.module.entity.InfoRoleType;
import com.xdf.creative.module.entity.InfoType;
import com.xdf.creative.module.entity.SysRole;
import com.xdf.creative.module.entity.SysUser;
import com.xdf.creative.module.mapper.InfoRoleTypeMapper;
import com.xdf.creative.module.service.InfoRoleTypeService;
import com.xdf.creative.module.service.InfoTypeService;
import com.xdf.creative.module.service.SysRoleService;
import com.xdf.creative.module.service.SysUserService;
import com.xdf.creative.util.page.ApiResult;
import com.xdf.creative.util.page.PageTool;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.io.Serializable;
import java.util.Date;
import java.util.List;


/**
 * <p>
 * 角色类型 服务实现类
 * </p>
 *
 * @author lgw
 * @since 2020-04-02
 */
@Slf4j
@Service
@Transactional(rollbackFor = Exception.class)
public class InfoRoleTypeServiceImpl extends BaseServiceImpl<InfoRoleTypeMapper, InfoRoleType> implements InfoRoleTypeService {

    @Autowired
    private InfoRoleTypeMapper infoRoleTypeMapper;

    @Autowired
    private SysRoleService sysRoleService;

    @Autowired
    private InfoTypeService infoTypeService;

    @Autowired
    private SysUserService sysUserService;



    /**
     * 给角色授权新闻类型
     * @param infoRoleImpowerTypeQueryParam
     * @return
     * @throws Exception
     */
    @Override
    public ApiResult setTypeToRole(InfoRoleImpowerTypeQueryParam infoRoleImpowerTypeQueryParam) throws Exception {
        SysRole sysRole = sysRoleService.getById(infoRoleImpowerTypeQueryParam.getRoleId());
        if(null ==sysRole){
            return ApiResult.error(StatusCode.SYS_ROLE_EXIST_NO);
        }
       /* if(infoRoleImpowerTypeQueryParam.getInfoTypeList().isEmpty()){
            return ApiResult.error(StatusCode.SYS_ROLE_PERMISSION_EXIST);
        }*/
        this.remove(new QueryWrapper<InfoRoleType>().eq("role_id",sysRole.getId()));

        for (String typeId:infoRoleImpowerTypeQueryParam.getInfoTypeList()
        ) {
            InfoType infoType = infoTypeService.getOne(new QueryWrapper<InfoType>().eq("type_id",typeId));
            if(null!=infoType){
                InfoRoleType infoRoleType = new InfoRoleType();
                infoRoleType.setRoleId(sysRole.getId());
                infoRoleType.setCreateTime(new Date());
                infoRoleType.setUpdateTime(new Date());
                infoRoleType.setInfoTypeId(infoType.getId());
               this.saveOrUpdate(infoRoleType);
            }
        }
        return ApiResult.ok();
    }

    /**
     * 获取用户拥有的栏目类型树
     * @return
     * @throws Exception
     */
    @Override
    public List<Object> getRoleTypeTreeList() throws Exception {

        SysUser sysUser = sysUserService.getById(getUserId());
        if(null!=sysUser){
            ApiResult.fail("当前用户已失效，请刷新后登录！");
        }
        return baseMapper.getRoleTypeTreeList(sysUser.getId());
    }

    /**
     * 获取角色授权栏目类型树
     * @return
     * @throws Exception
     */
    @Override
    public List<Object> impowerTypeTreeList(Long roleId) throws Exception {
        SysRole sysRole = sysRoleService.getById(roleId);
        if(null==sysRole){
            ApiResult.fail("所选角色不存在或已经删除，请刷新后再试！");
        }
        return baseMapper.impowerTypeTreeList(roleId);
    }


    @Override
    public InfoRoleTypeQueryVo getInfoRoleTypeById(Serializable id) throws Exception {
        return infoRoleTypeMapper.getInfoRoleTypeById(id);
    }

    @Override
    public PageTool<InfoRoleTypeQueryVo> getInfoRoleTypePageList(InfoRoleTypeQueryParam infoRoleTypeQueryParam) throws Exception {
        Page page = setPageParam(infoRoleTypeQueryParam);
        IPage<InfoRoleTypeQueryVo> iPage = infoRoleTypeMapper.getInfoRoleTypePageList(page, infoRoleTypeQueryParam);
        return new PageTool(iPage);
    }

}
