package com.xdf.creative.module.service.impl;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.xdf.creative.base.params.creative.InfoStoreAddParam;
import com.xdf.creative.base.params.creative.InfoStoreQueryParam;
import com.xdf.creative.base.params.creative.InfoStoreUrlEntityParam;
import com.xdf.creative.base.params.creative.InfoStoreUrlParam;
import com.xdf.creative.base.service.impl.BaseServiceImpl;
import com.xdf.creative.base.vo.creative.InfoStoreQueryVo;
import com.xdf.creative.enums.OrganizeTypeEnum;
import com.xdf.creative.enums.StateEnum;
import com.xdf.creative.enums.StatusCode;
import com.xdf.creative.module.entity.InfoStore;
import com.xdf.creative.module.mapper.InfoStoreMapper;
import com.xdf.creative.module.service.InfoStoreService;
import com.xdf.creative.util.StringUtil;
import com.xdf.creative.util.UUIDUtil;
import com.xdf.creative.util.image.ImageUtils;
import com.xdf.creative.util.page.ApiResult;
import com.xdf.creative.util.page.PageTool;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.io.Serializable;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;


/**
 * <p>
 * 文件库 服务实现类
 * </p>
 *
 * @author lgw
 * @since 2020-03-31
 */
@Slf4j
@Service
@Transactional(rollbackFor = Exception.class)
public class InfoStoreServiceImpl extends BaseServiceImpl<InfoStoreMapper, InfoStore> implements InfoStoreService {

    @Autowired
    private InfoStoreMapper infoStoreMapper;

    @Value("${wx_basePath}")
    private String wxPath;


    public static ArrayList<String> fileTypeList = new ArrayList<String>() {{
        add("PDF");
        add("DOC");
        add("DOCX");
        add("XLS");
        add("XLSX");
        add("PPT");
        add("PPTX");
        add("PNG");
        add("JPG");
        add("TXT");
    }};

    /**
     * 增加文件到图片库
     * @param infoStoreAddParam
     * @return
     */
    @Override
    public ApiResult addStore(InfoStoreAddParam infoStoreAddParam) {
        InfoStore infoStore = new InfoStore();
        BeanUtils.copyProperties(infoStoreAddParam,infoStore);
        infoStore.setCreateTime(new Date());
        infoStore.setState(StateEnum.ENABLE.getKey());
        infoStore.setCreateUserId(getUserId());
        this.saveOrUpdate(infoStore);
        return ApiResult.ok();
    }

    /**
     * 把图片停用启用
     * @param id
     * @return
     */
    @Override
    public ApiResult delStore(Serializable id) {
        InfoStore infoStore = this.getById(id);
        if(!getUserId().equals(infoStore.getCreateUserId())){
            return ApiResult.fail("只能停用自己创建的图片！");
        }
        if(null==infoStore){
            return ApiResult.error(StatusCode.FORM_SUBMIT_UPDATE_VERIFY);
        }
        if(StateEnum.DISABLE.getKey().equals(infoStore.getState())){
            infoStore.setState(StateEnum.ENABLE.getKey());
        }else{
            infoStore.setState(StateEnum.DISABLE.getKey());
        }
        this.saveOrUpdate(infoStore);
        return ApiResult.ok();
    }

    /**
     * 用户图片库调用列表
     * @param infoStoreQueryParam
     * @return
     * @throws Exception
     */
    @Override
    public PageTool<InfoStoreQueryVo> getUserStorePage(InfoStoreQueryParam infoStoreQueryParam) throws Exception {
        if(OrganizeTypeEnum.ORGANIZE_PARK.getCode().equals(getOrganizeType())){
            infoStoreQueryParam.setCreateUserId(getUserId());
        }
        Page page = setPageParam(infoStoreQueryParam);
        IPage<InfoStoreQueryVo> iPage = infoStoreMapper.getUserStorePage(page, infoStoreQueryParam);
        return new PageTool(iPage);
    }


    @Override
    public InfoStoreQueryVo getInfoStoreById(Serializable id) throws Exception {
        return infoStoreMapper.getInfoStoreById(id);
    }


    /**
     * 后台管理图片库列表
     * @param infoStoreQueryParam
     * @return
     * @throws Exception
     */
    @Override
    public PageTool<InfoStoreQueryVo> getInfoStorePageList(InfoStoreQueryParam infoStoreQueryParam) throws Exception {

        if(OrganizeTypeEnum.ORGANIZE_PARK.getCode().equals(getOrganizeType())){
            infoStoreQueryParam.setCreateUserId(getUserId());
        }
        Page page = setPageParam(infoStoreQueryParam);
        IPage<InfoStoreQueryVo> iPage = infoStoreMapper.getInfoStorePageList(page, infoStoreQueryParam);
        return new PageTool(iPage);
    }

    @Override
    public ApiResult getUrlStort(InfoStoreUrlParam infoStoreUrlParam) {
        List<InfoStoreUrlEntityParam> fileList = new ArrayList<InfoStoreUrlEntityParam>();
        Date dt = new Date();
        SimpleDateFormat sdf =  new SimpleDateFormat("yyyy-MM-dd");
        String indexName = sdf.format(dt);
        List<InfoStoreUrlEntityParam> urlList = infoStoreUrlParam.getUrlList();
        for (InfoStoreUrlEntityParam infoStoreUrlEntityParam:urlList
             ) {
                if(!StringUtil.isEmpty(infoStoreUrlEntityParam.getType())&&fileTypeList.contains(infoStoreUrlEntityParam.getType().toUpperCase())&&!StringUtil.isEmpty(infoStoreUrlParam.getFilePath())) {
                    String fileName = indexName + UUIDUtil.getUUID();
                    if (ImageUtils.readFileByUrl(infoStoreUrlParam.getFilePath(), fileName, infoStoreUrlEntityParam.getType(),
                            infoStoreUrlEntityParam.getUrl())) {
                        InfoStoreUrlEntityParam infoStoreUrlEntityParamNew = new InfoStoreUrlEntityParam();
                        infoStoreUrlEntityParamNew.setNumber(infoStoreUrlEntityParam.getNumber()).setUrl(
                                wxPath + fileName + "." + infoStoreUrlEntityParam.getType()).setType(
                                infoStoreUrlEntityParam.getType()
                        );
                        fileList.add(infoStoreUrlEntityParamNew);

                    }
                }
        }

        return ApiResult.ok(fileList);
    }

}
