package com.xdf.creative.module.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.xdf.creative.base.params.IdParam;
import com.xdf.creative.base.params.creative.*;
import com.xdf.creative.base.service.impl.BaseServiceImpl;
import com.xdf.creative.base.vo.creative.SysOrganizeBackVo;
import com.xdf.creative.base.vo.creative.SysOrganizeQueryVo;
import com.xdf.creative.enums.OrganizeTypeEnum;
import com.xdf.creative.enums.StateEnum;
import com.xdf.creative.enums.StatusCode;
import com.xdf.creative.module.entity.SysOrganize;
import com.xdf.creative.module.entity.SysRegion;
import com.xdf.creative.module.mapper.SysOrganizeMapper;
import com.xdf.creative.module.mapper.SysRegionMapper;
import com.xdf.creative.module.service.SysOrganizeService;
import com.xdf.creative.module.service.SysRegionService;
import com.xdf.creative.module.service.SysUserRoleService;
import com.xdf.creative.module.service.SysUserService;
import com.xdf.creative.util.page.ApiResult;
import com.xdf.creative.util.page.PageTool;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.io.Serializable;
import java.util.Date;
import java.util.List;


/**
 * <p>
 * 组织信息 服务实现类
 * </p>
 *
 * @author DeanYe
 * @since 2019-11-05
 */
@Slf4j
@Service
@Transactional(rollbackFor = Exception.class)
public class SysOrganizeServiceImpl extends BaseServiceImpl<SysOrganizeMapper, SysOrganize> implements SysOrganizeService {

    @Autowired
    private SysOrganizeMapper sysOrganizeMapper;
    @Autowired
    private SysRegionMapper sysRegionMapper;

    @Autowired
    private SysRegionService sysRegionService;

    @Autowired
    private SysUserService sysUserService;

    @Autowired
    private SysUserRoleService sysUserRoleService;


    /**
     * 添加组织机构
     *
     * @param sysOrganizeAddParam
     * @return
     */
    @Override
    public ApiResult add(SysOrganizeAddParam sysOrganizeAddParam) throws Exception {
        //1检查企业名是否存在
        if (this.count(new QueryWrapper<SysOrganize>().eq("organize_name", sysOrganizeAddParam.getOrganizeName())) > 0) {
            return ApiResult.fail("当前组织名已经存在！");
        }

        SysRegion sysRegion = sysRegionService.getById(sysOrganizeAddParam.getPopedomId());
        if (null == sysRegion) {
            return ApiResult.fail("所选行政区域不存在！");
        }
        SysOrganize sysOrganize = new SysOrganize();
        sysOrganize.setCreateUserId(getUserId());
        BeanUtils.copyProperties(sysOrganizeAddParam, sysOrganize);
        if (OrganizeTypeEnum.ORGANIZE_DISTRICT.getCode().equals(sysOrganizeAddParam.getOrganizeType()) ||
                OrganizeTypeEnum.ORGANIZE_CITY.getCode().equals(sysOrganizeAddParam.getOrganizeType())) {
            SysOrganize sysOrganizeNew = this.getById(sysOrganizeAddParam.getParentId());
            if (null == sysOrganizeNew || (!sysOrganizeNew.getOrganizeType().equals(OrganizeTypeEnum.ORGANIZE_CITY.getCode()) && !sysOrganizeNew.getOrganizeType().equals(OrganizeTypeEnum.ORGANIZE_DISTRICT.getCode()))) {
                return ApiResult.fail("上级机构未选择！");
            }
            sysOrganize.setParentId(sysOrganizeAddParam.getParentId());
        } else if (OrganizeTypeEnum.ORGANIZE_PARK.getCode().equals(sysOrganizeAddParam.getOrganizeType())) {
            sysOrganize.setParentId(null);
        } else {
            return ApiResult.fail("未选择正确的账户类型！");
        }
        sysOrganize.setPopedomId(sysRegion.getId()).setState(StateEnum.ENABLE.getKey()).setSystemCreate(StateEnum.DISABLE.getKey());
        this.saveOrUpdate(sysOrganize);
        return ApiResult.ok();
    }

    /**
     * 修改文创办组织信息
     *
     * @param sysOrganizeEditParam
     * @return
     */
    @Override
    public ApiResult editMange(SysOrganizeEditParam sysOrganizeEditParam) throws Exception {
        SysOrganize sysOrganize = this.getById(sysOrganizeEditParam.getId());
        if (null == sysOrganize) {
            return ApiResult.error(StatusCode.FORM_SUBMIT_ID_VERIFY);
        }
        if (null != sysOrganizeEditParam.getPopedomId() && sysOrganizeEditParam.getPopedomId() != sysOrganize.getPopedomId()) {
            SysRegion sysRegion = sysRegionService.getById(sysOrganizeEditParam.getPopedomId());
            if (null == sysRegion) {
                return ApiResult.fail("所选行政区域不存在！");
            }
            sysOrganize.setPopedomId(sysRegion.getId());
        }
        if (null != sysOrganizeEditParam.getParentId() && sysOrganizeEditParam.getParentId() != sysOrganize.getParentId()) {
            SysOrganize sysOrganizeNew = this.getById(sysOrganizeEditParam.getParentId());
            if (null == sysOrganizeNew || (!sysOrganizeNew.getOrganizeType().equals(OrganizeTypeEnum.ORGANIZE_CITY.getCode()) && !sysOrganizeNew.getOrganizeType().equals(OrganizeTypeEnum.ORGANIZE_DISTRICT.getCode()))) {
                return ApiResult.fail("上级机构未选择！");
            }
            sysOrganize.setParentId(sysOrganizeNew.getId());
        }
        sysOrganize.setOrganizeName(sysOrganizeEditParam.getOrganizeName());
        sysOrganize.setUpdateTime(new Date());
        this.saveOrUpdate(sysOrganize);
        return ApiResult.ok();
    }


    @Override
    public ApiResult enabledOrganize(IdParam idParam) {
        if (null == idParam) {
            return ApiResult.fail("未选择组织");
        }
        SysOrganize sysOrganize = this.getById(idParam.getId());
        if (null == sysOrganize) {
            return ApiResult.error(StatusCode.FORM_SUBMIT_ID_VERIFY);
        }

        if (sysOrganize.getState().equals(StateEnum.ENABLE.getKey())) {
            sysOrganize.setState(StateEnum.DISABLE.getKey());
        } else {
            sysOrganize.setState(StateEnum.ENABLE.getKey());
        }
        this.saveOrUpdate(sysOrganize);

        return ApiResult.ok();
    }


    /**
     * 获取组织机构资源数
     *
     * @return
     * @throws Exception
     */
    @Override
    public List<Object> getOrganizeTreeList() throws Exception {

        return baseMapper.getTreeOrganizeList(getRegionId(""));
    }

    @Override
    public String getRootOrganizeId() throws Exception {
        if (OrganizeTypeEnum.ORGANIZE_DISTRICT.getCode().equals(getOrganizeType())) {
            return "3";
        } else {
            return "1";
        }
    }


    @Override
    public SysOrganizeQueryVo getSysOrganizeById(Serializable id) throws Exception {
        return sysOrganizeMapper.getSysOrganizeById(id);
    }

    /**
     * 后台获取文创办组织
     *
     * @param sysOrganizeBackParam
     * @return
     * @throws Exception
     */
    @Override
    public PageTool<SysOrganizeBackVo> getManagePageList(SysOrganizeBackParam sysOrganizeBackParam) throws Exception {
        String regionId = getRegionId(sysOrganizeBackParam.getRegionId());
        sysOrganizeBackParam.setRegionId(regionId);
        Page page = setPageParam(sysOrganizeBackParam);
        IPage<SysOrganizeBackVo> iPage = sysOrganizeMapper.getManagePageList(page, sysOrganizeBackParam);
        return new PageTool(iPage);
    }

    /**
     * 后台获取园区组织
     *
     * @param sysOrganizeBackParam
     * @return
     * @throws Exception
     */
    @Override
    public PageTool<SysOrganizeBackVo> getParkPageList(SysOrganizeBackParam sysOrganizeBackParam) throws Exception {
        String regionId = getRegionId(sysOrganizeBackParam.getRegionId());
        sysOrganizeBackParam.setRegionId(regionId);
        Page page = setPageParam(sysOrganizeBackParam);
        IPage<SysOrganizeBackVo> iPage = sysOrganizeMapper.getParkPageList(page, sysOrganizeBackParam);
        return new PageTool(iPage);
    }


    @Override
    public PageTool<SysOrganizeQueryVo> getSysOrganizePageList(SysOrganizeQueryParam sysOrganizeQueryParam) throws Exception {
        Page page = setPageParam(sysOrganizeQueryParam);
        IPage<SysOrganizeQueryVo> iPage = sysOrganizeMapper.getSysOrganizePageList(page, sysOrganizeQueryParam);
        return new PageTool(iPage);
    }


    @Override
    public boolean isEnableSysOrganize(IsEnableSysOrganizeParam isEnableSysOrganizeParam) throws Exception {
        Integer count = sysOrganizeMapper.isEnableSysOrganize(isEnableSysOrganizeParam);
        return count > 0;
    }


}
