
package com.xdf.creative.module.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.xdf.creative.base.params.creative.SysPermissionCurrentUserParam;
import com.xdf.creative.base.params.creative.SysPermissionQueryParam;
import com.xdf.creative.base.params.creative.SysRoleImpowerPermissionQueryParam;
import com.xdf.creative.base.service.impl.BaseServiceImpl;
import com.xdf.creative.base.vo.creative.SysPermissionQueryVo;
import com.xdf.creative.base.vo.creative.SysPermissionUserVo;
import com.xdf.creative.enums.OrganizeTypeEnum;
import com.xdf.creative.enums.StateEnum;
import com.xdf.creative.enums.StatusCode;
import com.xdf.creative.module.entity.*;
import com.xdf.creative.module.mapper.SysPermissionMapper;
import com.xdf.creative.module.service.*;
import com.xdf.creative.support.exception.BusinessException;
import com.xdf.creative.util.StringUtil;
import com.xdf.creative.util.page.ApiResult;
import com.xdf.creative.util.page.PageTool;
import com.xdf.creative.util.tree.TreeConfig;
import com.xdf.creative.util.tree.Utils;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.io.Serializable;
import java.util.*;
import java.util.stream.Collectors;


/**
 * <pre>
 * 系统权限 服务实现类
 * </pre>
 *
 * @author DeanYe
 * @since 2019-10-25
 */
@Slf4j
@Service
public class SysPermissionServiceImpl extends BaseServiceImpl<SysPermissionMapper, SysPermission> implements SysPermissionService {

    @Autowired
    private SysPermissionMapper sysPermissionMapper;

    @Resource
    private SysRolePermissionService sysRolePermissionService;

    @Autowired
    private SysRoleService sysRoleService;


    @Autowired
    private OauthTokenService oauthTokenService;

    @Autowired
    private SysUserRoleService sysUserRoleService;


    /**
     * 获取角色授权资源树
     *
     * @param roleId
     * @return
     * @throws Exception
     */
    @Override
    public List<Object> impowerResourceTreeList(Long roleId) throws Exception {
        return sysPermissionMapper.impowerResourceTreeList(roleId);
    }

    /**
     * 获取用户已得到得权限 只包含菜单
     * @param userId
     * @return
     * @throws Exception
     */
    @Override
    public List<Object> getTreeMenusByUserId(Long userId) throws Exception {
        // 获取所有已启用的权限列表
        List<Object> list = sysPermissionMapper.getMenusByUserId(userId);
        TreeConfig config = new TreeConfig("resourceId", "parentResourceId", "parentResourceId", "01", "");
        List<Object> objectList = Utils.tree(list, config);
        return objectList;
    }

    /**
     * 获取用户已得到得权限 包含菜单和按钮
     * @param sysPermissionCurrentUserParam
     * @return
     * @throws Exception
     */
    @Override
    public List<SysPermission> currentUserResourceTreeList(SysPermissionCurrentUserParam sysPermissionCurrentUserParam) throws Exception {
        // 获取所有已启用的权限列表
        return sysPermissionMapper.currentUserResourceTreeList(sysPermissionCurrentUserParam);
    }




    /**
     * 给角色授权资源
     * @param sysRoleImpowerPermissionQueryParam
     * @return
     * @throws Exception
     */
    @Override
    @Transactional
    public ApiResult setPermissionToRoleByUserId(SysRoleImpowerPermissionQueryParam sysRoleImpowerPermissionQueryParam) throws Exception {
        SysRole sysRole = sysRoleService.getById(sysRoleImpowerPermissionQueryParam.getRoleId());
        if(null ==sysRole){
            return ApiResult.error(StatusCode.SYS_ROLE_EXIST_NO);
        }
        if(sysRole.getCode().equals("admin")){

            if(null==sysRoleImpowerPermissionQueryParam.getPermissionList()||sysRoleImpowerPermissionQueryParam.getPermissionList().size()<10) {
                return ApiResult.fail("管理员角色不允许修改！");
            }

        }
        if(sysRoleImpowerPermissionQueryParam.getPermissionList().isEmpty()){
            return ApiResult.error(StatusCode.SYS_ROLE_PERMISSION_EXIST);
        }
        //先删除角色资源关联表
        sysRolePermissionService.remove(new QueryWrapper<SysRolePermission>().eq("role_id",sysRole.getId()));
        for (String permissionId:sysRoleImpowerPermissionQueryParam.getPermissionList()
             ) {
            SysPermission sysPermission = this.getOne(new QueryWrapper<SysPermission>().eq("resource_id",permissionId));
            if(null!=sysPermission){
                SysRolePermission sysRolePermission = new SysRolePermission();
                sysRolePermission.setRoleId(sysRole.getId());
                sysRolePermission.setPermissionId(sysPermission.getResourceId());
                sysRolePermission.setState(StateEnum.ENABLE.getKey());
                sysRolePermission.setRemark(sysPermission.getName());
                sysRolePermissionService.saveOrUpdate(sysRolePermission);
            }
        }
        //删除角色下面用户的token
        List<SysUserRole> userRoleList = sysUserRoleService.list(new QueryWrapper<SysUserRole>().eq("role_id",sysRole.getId()));
        if(userRoleList.size()>0) {
            if (!oauthTokenService.removeTokenByUserList(userRoleList)) {
                log.error("角色变更授权，对应用户token未重置");
            }
        }
        return ApiResult.ok();
    }








    @Transactional(rollbackFor = Exception.class)
    @Override
    public boolean saveSysPermission(SysPermission sysPermission) throws Exception {
        sysPermission.setId(null);
        return super.save(sysPermission);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public boolean updateSysPermission(SysPermission sysPermission) throws Exception {
        // 获取权限
        SysPermission updateSysPermission = getById(sysPermission.getResourceId());
        if (updateSysPermission == null) {
            throw new BusinessException("权限不存在");
        }

        // 指定需改的字段
        updateSysPermission.setParentResourceId(sysPermission.getParentResourceId())
                .setLevel(sysPermission.getLevel())
                .setName(sysPermission.getName())
                .setState(sysPermission.getState())
                .setCode(sysPermission.getCode())
                .setIcon(sysPermission.getIcon())
                .setRemark(sysPermission.getRemark())
                .setSort(sysPermission.getSort())
                .setType(sysPermission.getType())
                .setUrl(sysPermission.getUrl())
                .setUpdateTime(new Date());
        return super.updateById(updateSysPermission);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public boolean deleteSysPermission(String resourceId) throws Exception {
        boolean isExists = sysRolePermissionService.isExistsByPermissionId(resourceId);
        if (isExists) {
            throw new BusinessException("该权限存在角色关联关系，不能删除");
        }
        return super.removeById(resourceId);
    }

    @Override
    public SysPermissionQueryVo getSysPermissionById(Serializable id) throws Exception {
        return sysPermissionMapper.getSysPermissionById(id);
    }

    @Override
    public PageTool<SysPermissionQueryVo> getSysPermissionPageList(SysPermissionQueryParam sysPermissionQueryParam) throws Exception {
        Page page = setPageParam(sysPermissionQueryParam);
        IPage<SysPermissionQueryVo> iPage = sysPermissionMapper.getSysPermissionPageList(page, sysPermissionQueryParam);
        return new PageTool(iPage);
    }

    @Override
    public boolean isExistsByPermissionIds(List<String> permissionIds) {
        QueryWrapper queryWrapper = new QueryWrapper();
        queryWrapper.in("resourceId", permissionIds);
        return sysPermissionMapper.selectCount(queryWrapper).intValue() == permissionIds.size();
    }

    @Override
    public List<SysPermission> getAllMenuList() throws Exception {
        SysPermission sysPermission = new SysPermission().setState(StateEnum.ENABLE.ordinal());
        // 获取所有已启用的权限列表
        return sysPermissionMapper.selectList(new QueryWrapper(sysPermission));
    }



    @Override
    public List<SysPermission> getMenuListByUserId(Long userId) throws Exception {
        return sysPermissionMapper.getMenuListByUserId(userId);
    }


    @Override
    public Set<String> getPermissionUrlByUserId(Long userId) throws Exception {
        List<String> permissionUrls = sysPermissionMapper.getPermissionUrlByUserId(userId);

        HashSet<String> stringHashSet = new HashSet<>();
        permissionUrls.stream().forEach(s -> {
            if (StringUtil.isNotEmpty(s)) {
                if (s.contains(";")) {
                    String[] url = s.split(";");
                    for (String s1 : url) {
                        stringHashSet.add(s1);
                    }
                } else {
                    stringHashSet.add(s);
                }
            }
        });
        return stringHashSet;
    }

    @Override
    public Map<String, Object> getPermissionByUserId(Long userId) {

        Map<String, Object> map = new HashMap<>();

        List<SysPermissionUserVo>  sysPermissionUserVoList=  sysPermissionMapper.getPermissionByUserId(userId);

        HashSet<String> stringHashSet = new HashSet<>();
        sysPermissionUserVoList.stream().forEach(s -> {
            if (StringUtil.isNotEmpty(s.getUrl())) {
                if (s.getUrl().contains(";")) {
                    String[] url = s.getUrl().split(";");
                    for (String s1 : url) {
                        stringHashSet.add(s1);
                    }
                } else {
                    stringHashSet.add(s.getUrl());
                }
            }
        });
        map.put("url",stringHashSet);
        map.put("resource", sysPermissionUserVoList.stream().map(p -> p.getResourceId()).collect(Collectors.toList()));

        return map;
    }


    @Override
    public List<String> getSkipAuthUrls() throws Exception {
        List<String> skipAuthUrls = sysPermissionMapper.getSkipAuthUrls();
        return skipAuthUrls;
    }
}
