
package com.xdf.creative.module.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.xdf.creative.base.params.creative.AddSysRoleParam;
import com.xdf.creative.base.params.creative.SysRoleQueryParam;
import com.xdf.creative.base.params.creative.UpdateSysRoleParam;
import com.xdf.creative.base.service.impl.BaseServiceImpl;
import com.xdf.creative.base.vo.creative.SysRoleQueryVo;
import com.xdf.creative.enums.StateEnum;
import com.xdf.creative.enums.StatusCode;
import com.xdf.creative.module.entity.SysRole;
import com.xdf.creative.module.entity.SysUserRole;
import com.xdf.creative.module.mapper.SysRoleMapper;
import com.xdf.creative.module.service.*;
import com.xdf.creative.support.exception.BusinessException;
import com.xdf.creative.support.exception.DaoException;
import com.xdf.creative.util.StringUtil;
import com.xdf.creative.util.convert.SysRoleConvert;
import com.xdf.creative.util.page.ApiResult;
import com.xdf.creative.util.page.PageTool;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.collections4.SetUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.io.Serializable;
import java.util.Date;
import java.util.HashSet;
import java.util.List;
import java.util.Set;


/**
 * <pre>
 * 系统角色 服务实现类
 * </pre>
 *
 * @author DeanYe
 * @since 2019-10-24
 */
@Slf4j
@Service
public class SysRoleServiceImpl extends BaseServiceImpl<SysRoleMapper, SysRole> implements SysRoleService {

    @Autowired
    private SysRoleMapper sysRoleMapper;

    @Resource
    private SysPermissionService sysPermissionService;

    @Resource
    private SysRolePermissionService sysRolePermissionService;

    @Resource
    private SysUserService sysUserService;

    @Resource
    private SysUserRoleService sysUserRoleService;

    @Autowired
    private SysRoleService sysRoleService;

    /**
     * 添加角色
     * @param sysRoleQueryParam
     * @return
     */
    @Override
    public ApiResult addSysRole(SysRoleQueryParam sysRoleQueryParam) {


        SysRole sysRole = new SysRole();
        if(this.count(new QueryWrapper<SysRole>().eq("name",sysRoleQueryParam.getName()).or().eq("code",sysRoleQueryParam.getCode()))>0){
            return ApiResult.fail("角色名或code在系统中已经存在！");
        }
        BeanUtils.copyProperties(sysRoleQueryParam, sysRole);
        List<SysRoleQueryVo> roleList = this.getUserRoleByUserId(getUserId());
        int level = 99;
        for (SysRoleQueryVo sysRoleQueryVo : roleList
        ) {
            if (sysRoleQueryVo.getLevel() < level) {
                level = sysRoleQueryVo.getLevel();
            }
        }
        if(sysRoleQueryParam.getLevel()<level){
            return ApiResult.fail("所选角色等级不能高于本身！");
        }
        sysRole.setState(StateEnum.ENABLE.getKey()).setLevel(sysRoleQueryParam.getLevel());
        sysRole.setType(StateEnum.ENABLE.getKey());
        sysRole.setDeleted(StateEnum.DISABLE.getKey());
        sysRole.setRemark(sysRoleQueryParam.getRemark());
        this.save(sysRole);
        return ApiResult.ok();
    }

    /**
     * 修改角色
     * @param sysRoleQueryParam
     * @return
     */
    @Override
    public ApiResult updateSysRole(SysRoleQueryParam sysRoleQueryParam) {
        if (null == sysRoleQueryParam.getId()) {
            return ApiResult.ok(StatusCode.FORM_SUBMIT_ID_VERIFY);
        }
        if(StringUtil.isEmpty(sysRoleQueryParam.getName())){
            return ApiResult.fail("角色名称不能为空！");
        }
        SysRole sysRole = this.getById(sysRoleQueryParam.getId());
        if (null == sysRole) {
            return ApiResult.error(StatusCode.FORM_SUBMIT_UPDATE_VERIFY);
        }
        if(!sysRole.getName().equals(sysRoleQueryParam.getName())){
            if(this.count(new QueryWrapper<SysRole>().eq("name",sysRoleQueryParam.getName()))>0){
                return ApiResult.fail("角色名或code在系统中已经存在！");
            }
        }
        if(!sysRole.getLevel().equals(sysRoleQueryParam.getLevel())){
            List<SysRoleQueryVo> roleList = this.getUserRoleByUserId(getUserId());
            int level = 99;
            for (SysRoleQueryVo sysRoleQueryVo : roleList
            ) {
                if (sysRoleQueryVo.getLevel() < level) {
                    level = sysRoleQueryVo.getLevel();
                }
            }
            if(sysRoleQueryParam.getLevel()<level){
                return ApiResult.fail("所选角色等级不能高于本身！");
            }
        }
        sysRole.setName(sysRoleQueryParam.getName()).setLevel(sysRoleQueryParam.getLevel());
        sysRole.setRemark(sysRoleQueryParam.getRemark());
        sysRole.setUpdateTime(new Date());
        this.saveOrUpdate(sysRole);
        return ApiResult.ok();
    }

    /**
     * 删除角色
     * @param roleId
     * @return
     * @throws Exception
     */
    @Transactional(rollbackFor = Exception.class)
    @Override
    public ApiResult deleteSysRole(Long roleId) throws Exception {

        SysRole sysRole = this.getById(roleId);
        if(null==sysRole){
            return ApiResult.error(StatusCode.FORM_SUBMIT_ID_VERIFY);
        }
        if(StateEnum.DISABLE.getKey().equals(sysRole.getType())){
            return ApiResult.fail("系统角色不允许删除！");
        }

         if(sysUserRoleService.count(new QueryWrapper<SysUserRole>().eq("role_id",roleId))>0){
             return ApiResult.error(StatusCode.SYS_USER_ROLE_EXIST);
         }
        // 角色权限关系真实删除
        boolean deletePermissionResult = sysRolePermissionService.deleteSysRolePermissionByRoleId(roleId);
        if (!deletePermissionResult) {
            return ApiResult.error(StatusCode.SYS_ROLE_PERMISSION_DELETE);
        }
        // 角色逻辑删除
        boolean deleteRoleResult = removeById(roleId);
        if (!deleteRoleResult) {
            return ApiResult.error(StatusCode.SYS_USER_ROLE_DELETE);
        }
        return ApiResult.ok();
    }

    /**
     * 获取角色列表
     * @return
     */
    @Override
    public ApiResult getRoleList() {

        List<SysRoleQueryVo> roleList =  this.getUserRoleByUserId(getUserId());
        int level=99;
        for (SysRoleQueryVo sysRoleQueryVo:roleList
             ) {
            if(sysRoleQueryVo.getLevel()<level){
                level = sysRoleQueryVo.getLevel();
            }
        }
        return ApiResult.ok(sysRoleMapper.getRoleList(level));
    }



    @Override
    public SysRoleQueryVo getSysRoleById(Serializable id) throws Exception {
        return sysRoleMapper.getSysRoleById(id);
    }

    @Override
    public PageTool<SysRoleQueryVo> getSysRolePageList(SysRoleQueryParam sysRoleQueryParam) throws Exception {
        Page page = setPageParam(sysRoleQueryParam);
        IPage<SysRoleQueryVo> iPage = sysRoleMapper.getSysRolePageList(page, sysRoleQueryParam);
        return new PageTool(iPage);
    }

    @Override
    public boolean isEnableSysRole(Long id) throws Exception {
        SysRole sysRole = new SysRole()
                .setId(id)
                .setState(StateEnum.ENABLE.ordinal());
        int count = sysRoleMapper.selectCount(new QueryWrapper<>(sysRole));
        return count > 0;
    }

    @Override
    public boolean isEnableSysRole(Set<Long> ids) throws Exception {

        for (Long id : ids) {
            SysRole sysRole = new SysRole()
                    .setId(id)
                    .setState(StateEnum.ENABLE.ordinal());
            int count = sysRoleMapper.selectCount(new QueryWrapper<>(sysRole));
            if (count == 0) {
                return false;
            }
        }
        return true;
    }

    @Override
    public boolean isExistsByCode(String code) throws Exception {
        SysRole sysRole = new SysRole().setCode(code);
        return sysRoleMapper.selectCount(new QueryWrapper<>(sysRole)) > 0;
    }


    @Override
    public boolean isExistsByRoleName(String roleName) throws Exception {
        SysRole sysRole = new SysRole().setName(roleName);
        return sysRoleMapper.selectCount(new QueryWrapper<>(sysRole)) > 0;
    }

    @Override
    public List<SysRoleQueryVo> getUserRoleByUserId(Long userId) {
        return sysRoleMapper.getUserRoleByUserId(userId);
    }


}
