package com.xdf.creative.shiro.filter;

import cn.hutool.core.collection.CollectionUtil;
import com.alibaba.fastjson.JSON;
import com.xdf.creative.base.vo.creative.OauthTokenQueryVo;
import com.xdf.creative.enums.ApiCode;
import com.xdf.creative.module.entity.OauthToken;
import com.xdf.creative.module.entity.SysUser;
import com.xdf.creative.module.service.OauthTokenService;
import com.xdf.creative.module.service.SysPermissionService;
import com.xdf.creative.module.service.SysUserService;
import com.xdf.creative.shiro.jwt.JwtProperties;
import com.xdf.creative.shiro.jwt.JwtUtil;
import com.xdf.creative.shiro.jwt.SaltUtil;
import com.xdf.creative.util.BeanUtil;
import com.xdf.creative.util.StringUtil;
import com.xdf.creative.util.page.ApiResult;
import org.apache.shiro.web.util.WebUtils;
import org.jasig.cas.client.util.AbstractCasFilter;
import org.jasig.cas.client.validation.Assertion;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.web.servlet.HandlerInterceptor;
import org.springframework.web.servlet.ModelAndView;

import javax.servlet.ServletResponse;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;
import java.io.PrintWriter;
import java.text.SimpleDateFormat;
import java.time.Duration;
import java.util.*;

/**
 * @author : lgw
 * @date : 11:00 2020/3/5
 */

@Component
public class ConfigPathInterceptor implements HandlerInterceptor {
    private final static Logger log = LoggerFactory.getLogger(HandlerInterceptor.class);

    @Autowired
    private SysUserService sysUserService;
    @Autowired
    private OauthTokenService oauthTokenService;
    @Autowired
    private JwtProperties jwtProperties;


    @Override
    public boolean preHandle(HttpServletRequest request, HttpServletResponse response, Object handler) throws Exception {
        log.info(request.getRequestURI());

       String token = request.getHeader("token");
        if (null == token||StringUtil.isEmpty(token)||token.length()<50) {
            ApiResult result = new ApiResult();
            result.setCode(ApiCode.TOKEN_INVALID.getCode());
            result.setMsg(ApiCode.TOKEN_INVALID.getMsg());
            getResponseResult(response, result);
            return false;
        }
        if(request.getRequestURI().contains("logout")){
            return true;
        }
        setSysUserServiceBean();
        setOauthTokenServiceBean();
        if(!verifyToken(token,request,response)) return false;
        return true;
    }

    @Override
    public void postHandle(HttpServletRequest request, HttpServletResponse response, Object handler,
                           ModelAndView modelAndView) throws Exception {
    }

    @Override
    public void afterCompletion(HttpServletRequest request, HttpServletResponse response, Object handler, Exception ex)
            throws Exception {
    }



/**
     * 验证token
     * 以前版本遗留问题，token处理方式不对 后期整改
     * @param token
     * @return
     */

    public boolean verifyToken(String token,HttpServletRequest request, HttpServletResponse response) throws Exception {
        String requestUrl = request.getRequestURI();
        ApiResult result = new ApiResult();
        //token失效 先检查是否存在 不存在则直接令牌过去重新登录
        OauthTokenQueryVo  oauthTokenQueryVo= oauthTokenService.getOauthTokenByToken(token);
        if (jwtProperties==null){
            setJwtPropertiesBean();
        }
        if (JwtUtil.isExpired(token)) {
            //先查token是否存在
            if(null==oauthTokenQueryVo){
                log.error("令牌过期");
                result.setCode(ApiCode.TOKEN_INVALID.getCode());
                result.setMsg(ApiCode.TOKEN_INVALID.getMsg());
                getResponseResult(response, result);
                return  false;
            }else{
                if(new Date().getTime()-oauthTokenQueryVo.getUpdateTime().getTime()>jwtProperties.getExpireSecond()*1000){
                    result.setCode(ApiCode.TOKEN_INVALID.getCode());
                    result.setMsg(ApiCode.TOKEN_INVALID.getMsg());
                    getResponseResult(response, result);
                    return  false;
                }/*else{
                    return true;

                }*/

//                setJwtPropertiesBean();
//                String oldToken = oauthTokenQueryVo.getAccessToken();
//                Long userId = oauthTokenQueryVo.getUserId();
//               SysUser sysUser =  sysUserService.getById(userId);
//                // 获取数据库中保存的盐值
//                String newSalt = SaltUtil.getSalt(sysUser.getSalt(), jwtProperties);
//                Long expireSecond = jwtProperties.getExpireSecond();
//                String newToken = JwtUtil.generateToken(userId, sysUser.getUsername(), sysUser.getOrganizeId(), sysUser.getUserType(), newSalt, Duration.ofSeconds(expireSecond));
//                log.error("令牌过期");
//                oauthTokenQueryVo.setAccessToken(newToken);
//                oauthTokenQueryVo.setExpireTime(JwtUtil.getExpireDate(newToken));
//                OauthToken oauthToken = new OauthToken();
//                BeanUtils.copyProperties(oauthTokenQueryVo,oauthToken);
//                oauthTokenService.saveOrUpdate(oauthToken);
//
//                result.setCode(ApiCode.REFRESH_TOKEN_SUCCESS.getCode());
//                result.setMsg(ApiCode.REFRESH_TOKEN_SUCCESS.getMsg());
//                result.setData(newToken);
//                getResponseResult(response, result);
//                return  true;

            }

        }
        String userName = JwtUtil.getUsername(token);
        Long userId = JwtUtil.getUserId(token);
        if (StringUtil.isEmpty(userName) || null==userId) {
            log.error(ApiCode.TOKEN_INVALID.getMsg());
            result.setCode(ApiCode.TOKEN_INVALID.getCode());
            result.setMsg(ApiCode.TOKEN_INVALID.getMsg());
            getResponseResult(response, result);
            return  false;
        }
        //先查token是否存在
        if(null==oauthTokenQueryVo){
            log.error("该token未登录，非法访问!");
            result.setCode(ApiCode.TOKEN_INVALID.getCode());
            result.setMsg(ApiCode.TOKEN_INVALID.getMsg());
            getResponseResult(response, result);
            return false;
        }else{
            //更新更新时间
            if (new Date().getTime() - oauthTokenQueryVo.getUpdateTime().getTime() > jwtProperties.getRefreshTokenCountdown() * 1000) {
                //更新更新时间
                OauthToken oauthToken = new OauthToken();
                BeanUtils.copyProperties(oauthTokenQueryVo, oauthToken);
                oauthToken.setUpdateTime(new Date());
                oauthTokenService.saveOrUpdate(oauthToken);
            }
        }
        //根据用户名去数据库查询用户信息
        SysUser user = null;
        //获取用户信息
        try {
            user = sysUserService.getSysUserByUserName(userName);
        } catch (Exception e) {
            log.error("用户 { " + userName + " } 不存在 ");
            result.setCode(ApiCode.USER_EXIST.getCode());
            result.setMsg(ApiCode.USER_EXIST.getMsg());
            getResponseResult(response, result);
            return false;
        }
        if (user == null) {
            //这里返回后会报出对应异常
            result.setCode(ApiCode.USER_EXIST.getCode());
            result.setMsg(ApiCode.USER_EXIST.getMsg());
            getResponseResult(response, result);
            return false;
        }
        List<String> permissionList = Arrays.asList(oauthTokenQueryVo.getPermissions().trim().split(","));
        boolean permissionflag = false;
        for (String permissionUrl:permissionList ) {
            if(permissionUrl.contains(requestUrl.replaceAll("/wcapi",""))){
               return true;
            }
        }
        if(!permissionflag){
            log.error("该用户没有权限访问"+requestUrl);
            result.setCode(ApiCode.NOT_PERMISSION.getCode());
            result.setMsg(ApiCode.NOT_PERMISSION.getMsg());
            getResponseResult(response, result);
            return false;
        }


        return true;
    }
/*
*
     * 返回结果
     *
     * @param response
     */

    public void getResponseResult(ServletResponse response, ApiResult result) {
        response.setCharacterEncoding("UTF-8");
        response.setContentType("application/json;charset=utf-8");
        PrintWriter printWriter = null;
        try {
            printWriter = WebUtils.toHttp(response).getWriter();
            printWriter.write(JSON.toJSONString(result));
        } catch (Exception e) {
            log.error(e.getMessage(), e);
        } finally {
            if (null != printWriter) {
                printWriter.close();
            }
        }
    }

    public void setSysUserServiceBean() {
        if (null == sysUserService) {
            sysUserService = BeanUtil.getBean(SysUserService.class);
        }
    }

    public void setOauthTokenServiceBean() {
        if (null == oauthTokenService) {
            oauthTokenService = BeanUtil.getBean(OauthTokenService.class);
        }
    }

    public void setJwtPropertiesBean() {
        if (null == jwtProperties) {
            jwtProperties = BeanUtil.getBean(JwtProperties.class);
        }
    }


}


