package com.xdf.creative.shiro.filter;

import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.annotation.Configuration;
import org.springframework.web.servlet.config.annotation.*;

import java.util.List;

/**
 * @author : lgw
 * @date : 11:07 2020/3/5
 */
@Configuration
public class InterceptorConfiguration implements WebMvcConfigurer {
    @Value("${auth_skip_urls}")
    private List<String> skipAuthUrls;

    @Value("${upload_basePath}")
    private String basePath;
    @Override
    public void addInterceptors(InterceptorRegistry registry) {
        //注册TestInterceptor拦截器
        InterceptorRegistration registration = registry.addInterceptor(new ConfigPathInterceptor());
        registration.addPathPatterns("/**")
                .excludePathPatterns(                         //添加不拦截路径
                        skipAuthUrls
                ).excludePathPatterns("/swagger-resources/**", "/webjars/**", "/v2/**", "/swagger-ui.html/**");                      //所有路径都被拦截
    }


    @Override
    public void addResourceHandlers(ResourceHandlerRegistry registry) {
        //路径前面要使用file协议，本地路径使用/分隔
        registry.addResourceHandler("/resource/**").addResourceLocations("file:" + basePath);
    }

    @Override
    public void addCorsMappings(CorsRegistry registry) {
        registry.addMapping("/**").allowedOrigins("*").allowedMethods("GET", "POST", "OPTIONS", "PUT")
                .allowedHeaders("Content-Type", "X-Requested-With", "accept", "Origin", "Access-Control-Request-Method",
                        "Access-Control-Request-Headers")
                .exposedHeaders("Access-Control-Allow-Origin", "Access-Control-Allow-Credentials")
                .allowCredentials(true).maxAge(3600);
    }

    /*@Override
    public void addCorsMappings(CorsRegistry registry) {
        registry.addMapping("/**")
                .allowedOrigins("*")
                .allowCredentials(true)
                .allowedMethods("GET", "POST", "PUT", "DELETE", "OPTIONS")
                .maxAge(3600);
      *//*  registry.addMapping("/**").allowedOrigins("*").allowedMethods("GET", "POST", "OPTIONS", "PUT")
                .allowedHeaders("Content-Type", "X-Requested-With", "accept", "Origin", "Access-Control-Request-Method",
                        "Access-Control-Request-Headers")
                .exposedHeaders("Access-Control-Allow-Origin", "Access-Control-Allow-Credentials")
                .allowCredentials(true).maxAge(3600);*//*
    }*/
}
