package com.xdf.creative.support.exception;

import com.xdf.creative.enums.ApiCode;
import com.xdf.creative.util.page.ApiResult;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.ControllerAdvice;
import org.springframework.web.bind.annotation.ExceptionHandler;
import org.springframework.web.bind.annotation.ResponseBody;

import javax.servlet.http.HttpServletRequest;

/**
 * 全局异常处理器
 *
 * @author Yuzhe Ma
 * @date 2018/11/12
 */
@ControllerAdvice
public class GlobalExceptionHandler {
    private static final Logger logger = LoggerFactory.getLogger(GlobalExceptionHandler.class);

    /**
     * 处理 Exception 异常
     *
     * @param httpServletRequest httpServletRequest
     * @param e                  异常
     * @return
     */
    @ResponseBody
    @ExceptionHandler(value = BusinessException.class)
    public ApiResult busExceptionHandler(HttpServletRequest httpServletRequest, BusinessException e) {
        logger.error("服务错误:", e);
        return ApiResult.result(ApiCode.getApiCode(e.getErrorCode()));
    }



    /**
     * 处理 LoginException 异常
     *
     * @param httpServletRequest httpServletRequest
     * @param e                  异常
     * @return
     */
    @ResponseBody
    @ExceptionHandler(value = SysLoginException.class)
    public ApiResult loginExceptionHandler(HttpServletRequest httpServletRequest, SysLoginException e) {
        logger.info("业务异常。code:" + e.getErrorCode() + "msg:" + e.getMessage());
        return ApiResult.result(ApiCode.getApiCode(e.getErrorCode()));
    }
}
