/*
package com.xdf.creative.util.excel;

import com.xdf.creative.util.page.ApiResult;
import org.apache.poi.hssf.usermodel.HSSFDateUtil;
import org.apache.poi.hssf.usermodel.HSSFWorkbook;
import org.apache.poi.ss.usermodel.*;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;
import org.springframework.web.multipart.MultipartFile;

import java.io.IOException;
import java.lang.reflect.Field;
import java.lang.reflect.Method;
import java.text.SimpleDateFormat;
import java.util.*;

*/
/**
 * @author : lgw
 * @date : 14:15 2020/5/7
 *//*

public class ExcelUtil {


    public static final String XLS = ".xls";
    public static final String XLSX = ".xlsx";
    private SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");

    public static ApiResult importExcel(MultipartFile file) {
        try {
            Workbook workbook = null;
            String filename = file.getOriginalFilename();
            if (filename.endsWith(XLS)) {
                workbook = new HSSFWorkbook(file.getInputStream());
            } else if (filename.endsWith(XLSX)) {
                workbook = new XSSFWorkbook(file.getInputStream());
            } else {
                return ApiResult.fail("文件读取失败，请确认导入的excel后缀名为xls或者xlsx!");
            }
            Sheet sheet = workbook.getSheetAt(0);
            //获取sheet的行数
            int rows = sheet.getPhysicalNumberOfRows();
            for (int i = 0; i < 2; i++) {
                //过滤表头行
                if (i == 0) {
                    continue;
                }
                if (i == 1) {
                    Row rowTitle = sheet.getRow(1);
                    if(rowTitle.getLastCellNum()!=9){
                        return ApiResult.fail("文件上传失败（下载Excel模板格式不能更改）");
                    }
                    for (int j=0;j<rowTitle.getLastCellNum();j++){
                        Cell cell = rowTitle.getCell(j);
                        if(j==1){
                            if(!"企业名称".equals(cell.getStringCellValue())){
                                return ApiResult.fail("上传错误,列名：企业名称不能更改");
                            }
                        }
                        if(j==0){
                            if(!"园区名称".equals(cell.getStringCellValue())){
                                return ApiResult.fail("上传错误,列名：园区名称不能更改");
                            }
                        }
                        if(j==2){
                            if(!"企业统一社会信用代码".equals(cell.getStringCellValue())){
                                return ApiResult.fail("上传错误,列名：企业统一社会信用代码不能更改");
                            }
                        }
                        if(j==3){
                            if(!"企业法人".equals(cell.getStringCellValue())){
                                return ApiResult.fail("上传错误,列名：企业法人不能更改");
                            }
                        }
                        if(j==4){
                            if(!"注册资本数字".equals(cell.getStringCellValue())){
                                return ApiResult.fail("上传错误,列名：注册资本数字不能更改");
                            }
                        }
                        if(j==5){
                            if(!"注册资本单位".equals(cell.getStringCellValue())){
                                return ApiResult.fail("上传错误,列名：园注册资本单位不能更改");
                            }
                        }if(j==6){
                            if(!"所属行业名称".equals(cell.getStringCellValue())){
                                return ApiResult.fail("上传错误,列名：所属行业名称不能更改");
                            }
                        }if(j==7){
                            if(!"成立日期".equals(cell.getStringCellValue())){
                                return ApiResult.fail("上传错误,列名：成立日期不能更改");
                            }
                        }if(j==8){
                            if(!"是否为个体户".equals(cell.getStringCellValue())){
                                return ApiResult.fail("上传错误,列名：是否为个体户不能更改");
                            }
                        }

                    }
                   return ApiResult.ok();
                }
            }

        } catch (IOException e) {
            e.printStackTrace();
            return ApiResult.fail("文件读取失败，请确认导入的excel后缀名为xls或者xlsx!");
        }
        return ApiResult.ok();
    }


    public <T> List<T> readExcelFileToDTO(MultipartFile file, Class<T> clazz) throws IOException {
        return readExcelFileToDTO(file, clazz, 0);
    }

    public <T> List<T> readExcelFileToDTO(MultipartFile file, Class<T> clazz, Integer sheetId) throws IOException {
//将文件转成workbook类型
        Workbook workbook = buildWorkbook(file);
//第一个表
        return readSheetToDTO(workbook.getSheetAt(sheetId), clazz);
    }

    public <T> List<T> readSheetToDTO(Sheet sheet, Class<T> clazz) throws IOException {
        List<T> result = new ArrayList<>();
        List<Map<String, String>> sheetValue = changeSheetToMapList(sheet);
        for (Map<String, String> valueMap : sheetValue) {
            T dto = buildDTOByClass(clazz, valueMap);
            if (dto != null) {
                result.add(dto);
            }
        }
        return result;
    }

    //类型转换
    private Workbook buildWorkbook(MultipartFile file) throws IOException {
        String filename = file.getOriginalFilename();
        if (filename.endsWith(XLS)) {
            return new HSSFWorkbook(file.getInputStream());
        } else if (filename.endsWith(XLSX)) {
            return new XSSFWorkbook(file.getInputStream());
        } else {
            throw new IOException("unknown file format: " + filename);
        }
    }

    private List<Map<String, String>> changeSheetToMapList(Sheet sheet) {
        List<Map<String, String>> result = new ArrayList<>();
        int rowNumber = sheet.getPhysicalNumberOfRows();
        String[] titles = getSheetRowValues(sheet.getRow(0)); // 第一行作为表头

        for (int i = 1; i < rowNumber; i++) {
            String[] values = getSheetRowValues(sheet.getRow(i));
            Map<String, String> valueMap = new HashMap<>();
            for (int j = 0; j < titles.length; j++) {
                valueMap.put(titles[j], values[j]);
            }
            result.add(valueMap);
        }
        return result;
    }

    private <T> T buildDTOByClass(Class<T> clazz, Map<String, String> valueMap) {
        try {
            T dto = clazz.newInstance();
            for (Field field : clazz.getDeclaredFields()) {
                Description desc = field.getAnnotation(Description.class);
                String value = valueMap.get(desc.showName());
                if (value != null) {
                    Method method = clazz.getMethod(getSetMethodName(field.getName()), field.getType());
                    method.invoke(dto, value);
                }
            }

            return dto;
        } catch (Exception e) {
            e.getStackTrace();
        }
        return null;
    }

    private String getSetMethodName(String name) {
        String firstChar = name.substring(0, 1);
        return "set" + firstChar.toUpperCase() + name.substring(1);
    }

    private String[] getSheetRowValues(Row row) {
        if (row == null) {
            return new String[]{};
        } else {
            int cellNumber = row.getLastCellNum();
            List<String> cellValueList = new ArrayList<>();
            for (int i = 0; i < cellNumber; i++) {
                cellValueList.add(getValueOnCell(row.getCell(i)));
            }
            return cellValueList.toArray(new String[0]);
        }
    }

    private String getValueOnCell(Cell cell) {

        if (cell == null) {
            return "";
        }
        switch (cell.getCellType()) {
            case STRING:
                return cell.getStringCellValue();
            case NUMERIC:
                if (DateUtil.isCellDateFormatted(cell)) {

                    Date date = HSSFDateUtil.getJavaDate(cell.getNumericCellValue());
                    return sdf.format(date);
                } else {
                    */
/* return String.format("%.2f", cell.getNumericCellValue());*//*

                    */
/**String.valueOf(cell.getNumericCellValue());*//*

                    return String.valueOf(cell.getNumericCellValue());
                }
            case BOOLEAN:
                return cell.getBooleanCellValue() ? "true" : "false";
            case FORMULA:
                try {
                    return cell.getStringCellValue();
                } catch (Exception e) {
                    return String.valueOf(cell.getNumericCellValue());
                    //String.format("%.2f", cell.getNumericCellValue());
                }
            default:
                return "";
        }
    }

    public static void main(String args[]) {

    }

}
*/
